## Info on typeshed's stubs for `Authlib`

### Upstream repo URL

[https://github.com/lepture/authlib](https://github.com/lepture/authlib)

### Stub distribution name

`types-Authlib`

### Version

The latest version of `types-Authlib` aims to provide accurate annotations for `Authlib==1.6.6`.

### Number of lines

3,611 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 70 unique allowlist entries for `Authlib` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `Authlib`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 373
    - Unannotated parameters: 1,477
    - Explicit `Any` parameters: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 8
- Returns:
    - Annotated returns: 707
    - Unannotated returns: 417
    - Explicit `Any` returns: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 71
- Variables:
    - Annotated variables: 652
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 258
- Class definitions:
    - Total class definitions: 273
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `Deprecated`

### Upstream repo URL

[https://github.com/tantale/deprecated](https://github.com/tantale/deprecated)

### Stub distribution name

`types-Deprecated`

### Version

The latest version of `types-Deprecated` aims to provide accurate annotations for `Deprecated~=1.3.1`.

### Number of lines

88 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `Deprecated` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `Deprecated`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 44
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 15
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 16
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 3
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `Flask-Cors`

### Upstream repo URL

[https://github.com/corydolphin/flask-cors](https://github.com/corydolphin/flask-cors)

### Stub distribution name

`types-Flask-Cors`

### Version

The latest version of `types-Flask-Cors` aims to provide accurate annotations for `Flask-Cors==6.0.*`.

### Number of lines

130 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `Flask-Cors` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `Flask-Cors`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 65
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 24
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 32
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 2
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `Flask-Migrate`

### Upstream repo URL

[https://github.com/miguelgrinberg/Flask-Migrate](https://github.com/miguelgrinberg/Flask-Migrate)

### Stub distribution name

`types-Flask-Migrate`

### Version

The latest version of `types-Flask-Migrate` aims to provide accurate annotations for `Flask-Migrate==4.1.*`.

### Number of lines

129 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `Flask-Migrate` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `Flask-Migrate`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 86
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 23
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 7
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 3
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `Flask-SocketIO`

### Upstream repo URL

[https://github.com/miguelgrinberg/flask-socketio](https://github.com/miguelgrinberg/flask-socketio)

### Stub distribution name

`types-Flask-SocketIO`

### Version

The latest version of `types-Flask-SocketIO` aims to provide accurate annotations for `Flask-SocketIO==5.6.*`.

### Number of lines

256 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 4 unique allowlist entries for `Flask-SocketIO` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `Flask-SocketIO`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 137
    - Unannotated parameters: 37
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 14
- Returns:
    - Annotated returns: 37
    - Unannotated returns: 15
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 21
    - Explicit `Any` variables: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 3
- Class definitions:
    - Total class definitions: 11
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `JACK-Client`

### Upstream repo URL

[https://github.com/spatialaudio/jackclient-python](https://github.com/spatialaudio/jackclient-python)

### Stub distribution name

`types-JACK-Client`

### Version

The latest version of `types-JACK-Client` aims to provide accurate annotations for `JACK-Client==0.5.*`.

### Number of lines

312 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `darwin` and `linux`.

Typeshed currently has 1 unique allowlist entry for `JACK-Client` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `JACK-Client`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 107
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 152
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 46
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 15
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `Jetson.GPIO`

### Upstream repo URL

[https://github.com/NVIDIA/jetson-gpio](https://github.com/NVIDIA/jetson-gpio)

### Stub distribution name

`types-Jetson.GPIO`

### Version

The latest version of `types-Jetson.GPIO` aims to provide accurate annotations for `Jetson.GPIO==2.1.12`.

### Number of lines

212 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 4 unique allowlist entries for `Jetson.GPIO` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `Jetson.GPIO`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 88
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 47
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 108
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 11
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `Markdown`

### Upstream repo URL

[https://github.com/Python-Markdown/markdown](https://github.com/Python-Markdown/markdown)

### Stub distribution name

`types-Markdown`

### Version

The latest version of `types-Markdown` aims to provide accurate annotations for `Markdown==3.10.*`.

### Number of lines

826 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 3 unique allowlist entries for `Markdown` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `Markdown`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 301
    - Unannotated parameters: 33
    - Explicit `Any` parameters: 17
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 231
    - Unannotated returns: 4
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 253
    - Explicit `Any` variables: 11
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 112
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `PyAutoGUI`

### Upstream repo URL

[https://github.com/asweigart/pyautogui](https://github.com/asweigart/pyautogui)

### Stub distribution name

`types-PyAutoGUI`

### Version

The latest version of `types-PyAutoGUI` aims to provide accurate annotations for `PyAutoGUI==0.9.*`.

### Number of lines

234 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `PyAutoGUI` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `PyAutoGUI`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 145
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 38
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 22
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 5
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `PyMeeus`

### Upstream repo URL

[https://github.com/architest/pymeeus](https://github.com/architest/pymeeus)

### Stub distribution name

`types-PyMeeus`

### Version

The latest version of `types-PyMeeus` aims to provide accurate annotations for `PyMeeus==0.5.*`.

### Number of lines

954 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `PyMeeus` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `PyMeeus`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 706
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 374
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 59
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 18
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `PyMySQL`

### Upstream repo URL

[https://github.com/PyMySQL/PyMySQL](https://github.com/PyMySQL/PyMySQL)

### Stub distribution name

`types-PyMySQL`

### Version

The latest version of `types-PyMySQL` aims to provide accurate annotations for `PyMySQL==1.1.*`.

### Number of lines

1,219 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 unique allowlist entries for `PyMySQL` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `PyMySQL`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 212
    - Unannotated parameters: 24
    - Explicit `Any` parameters: 8
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 3
- Returns:
    - Annotated returns: 127
    - Unannotated returns: 31
    - Explicit `Any` returns: 14
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 2
- Variables:
    - Annotated variables: 767
    - Explicit `Any` variables: 10
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 4
- Class definitions:
    - Total class definitions: 28
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `PyScreeze`

### Upstream repo URL

[https://github.com/asweigart/pyscreeze](https://github.com/asweigart/pyscreeze)

### Stub distribution name

`types-PyScreeze`

### Version

The latest version of `types-PyScreeze` aims to provide accurate annotations for `PyScreeze==1.0.1`.

### Number of lines

193 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` and `win32`.

Typeshed currently has 2 unique allowlist entries for `PyScreeze` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `PyScreeze`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 102
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 21
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 17
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 5
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `PySocks`

### Upstream repo URL

[https://github.com/Anorov/PySocks](https://github.com/Anorov/PySocks)

### Stub distribution name

`types-PySocks`

### Version

The latest version of `types-PySocks` aims to provide accurate annotations for `PySocks==1.7.1`.

### Number of lines

213 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 unique allowlist entries for `PySocks` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `PySocks`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 113
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 35
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 26
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 2
- Class definitions:
    - Total class definitions: 12
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `PyYAML`

### Upstream repo URL

[https://github.com/yaml/pyyaml](https://github.com/yaml/pyyaml)

### Stub distribution name

`types-PyYAML`

### Version

The latest version of `types-PyYAML` aims to provide accurate annotations for `PyYAML==6.0.*`.

### Number of lines

1,318 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 4 unique allowlist entries for `PyYAML` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `PyYAML`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 520
    - Unannotated parameters: 278
    - Explicit `Any` parameters: 46
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 4
- Returns:
    - Annotated returns: 222
    - Unannotated returns: 172
    - Explicit `Any` returns: 12
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 220
    - Explicit `Any` variables: 160
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 2
- Class definitions:
    - Total class definitions: 91
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `Pygments`

### Upstream repo URL

[https://github.com/pygments/pygments](https://github.com/pygments/pygments)

### Stub distribution name

`types-Pygments`

### Version

The latest version of `types-Pygments` aims to provide accurate annotations for `Pygments==2.19.*`.

### Number of lines

849 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 4 unique allowlist entries for `Pygments` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `Pygments`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 94
    - Unannotated parameters: 179
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 107
    - Unannotated returns: 77
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 5
- Variables:
    - Annotated variables: 376
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 193
- Class definitions:
    - Total class definitions: 94
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 1

---

## Info on typeshed's stubs for `RPi.GPIO`

### Upstream repo URL

[https://sourceforge.net/p/raspberry-gpio-python/code/](https://sourceforge.net/p/raspberry-gpio-python/code/)

### Stub distribution name

`types-RPi.GPIO`

### Version

The latest version of `types-RPi.GPIO` aims to provide accurate annotations for `RPi.GPIO==0.7.*`.

### Number of lines

56 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *skipped*

Stubtest is skipped in typeshed's CI for this package.

Typeshed currently has 0 allowlist entries for `RPi.GPIO` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `RPi.GPIO`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 28
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 18
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 26
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 2
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `Send2Trash`

### Upstream repo URL

[https://github.com/arsenetar/send2trash](https://github.com/arsenetar/send2trash)

### Stub distribution name

`types-Send2Trash`

### Version

The latest version of `types-Send2Trash` aims to provide accurate annotations for `Send2Trash==2.1.*`.

### Number of lines

15 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `Send2Trash` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `Send2Trash`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 4
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 4
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `TgCrypto`

### Upstream repo URL

[https://github.com/pyrogram/tgcrypto](https://github.com/pyrogram/tgcrypto)

### Stub distribution name

`types-TgCrypto`

### Version

The latest version of `types-TgCrypto` aims to provide accurate annotations for `TgCrypto==1.2.*`.

### Number of lines

7 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 6 unique allowlist entries for `TgCrypto` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `TgCrypto`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 20
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 6
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `WTForms`

### Upstream repo URL

[https://github.com/pallets-eco/wtforms](https://github.com/pallets-eco/wtforms)

### Stub distribution name

`types-WTForms`

### Version

The latest version of `types-WTForms` aims to provide accurate annotations for `WTForms~=3.2.1`.

### Number of lines

1,351 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 27 unique allowlist entries for `WTForms` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `WTForms`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 531
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 71
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 185
    - Unannotated returns: 0
    - Explicit `Any` returns: 14
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 141
    - Explicit `Any` variables: 29
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 100
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `WebOb`

### Upstream repo URL

[https://github.com/Pylons/webob](https://github.com/Pylons/webob)

### Stub distribution name

`types-WebOb`

### Version

The latest version of `types-WebOb` aims to provide accurate annotations for `WebOb==1.8.*`.

### Number of lines

2,222 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 99 unique allowlist entries for `WebOb` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `WebOb`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 799
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 80
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 609
    - Unannotated returns: 0
    - Explicit `Any` returns: 13
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 250
    - Explicit `Any` variables: 15
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 136
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `aiofiles`

### Upstream repo URL

[https://github.com/Tinche/aiofiles](https://github.com/Tinche/aiofiles)

### Stub distribution name

`types-aiofiles`

### Version

The latest version of `types-aiofiles` aims to provide accurate annotations for `aiofiles==25.1.*`.

### Number of lines

788 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` and `win32`.

Typeshed currently has 86 unique allowlist entries for `aiofiles` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `aiofiles`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 432
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 1
- Returns:
    - Annotated returns: 151
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 2
- Variables:
    - Annotated variables: 6
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 16
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `antlr4-python3-runtime`

### Upstream repo URL

[https://github.com/antlr/antlr4](https://github.com/antlr/antlr4)

### Stub distribution name

`types-antlr4-python3-runtime`

### Version

The latest version of `types-antlr4-python3-runtime` aims to provide accurate annotations for `antlr4-python3-runtime==4.13.*`.

### Number of lines

1,968 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` and `win32`.

Typeshed currently has 0 allowlist entries for `antlr4-python3-runtime` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `antlr4-python3-runtime`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 782
    - Unannotated parameters: 217
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 14
- Returns:
    - Annotated returns: 355
    - Unannotated returns: 338
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 424
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 219
- Class definitions:
    - Total class definitions: 142
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `assertpy`

### Upstream repo URL

[https://github.com/assertpy/assertpy](https://github.com/assertpy/assertpy)

### Stub distribution name

`types-assertpy`

### Version

The latest version of `types-assertpy` aims to provide accurate annotations for `assertpy==1.1.*`.

### Number of lines

226 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 6 unique allowlist entries for `assertpy` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `assertpy`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 88
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 8
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 89
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 21
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 15
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `atheris`

### Upstream repo URL

[https://github.com/google/atheris](https://github.com/google/atheris)

### Stub distribution name

`types-atheris`

### Version

The latest version of `types-atheris` aims to provide accurate annotations for `atheris==3.0.*`.

### Number of lines

88 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `atheris` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `atheris`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 54
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 41
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 9
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 9
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `auth0-python`

### Upstream repo URL

[https://github.com/auth0/auth0-python](https://github.com/auth0/auth0-python)

### Stub distribution name

`types-auth0-python`

### Version

The latest version of `types-auth0-python` aims to provide accurate annotations for `auth0-python==4.10.*`.

### Number of lines

1,683 (excluding blank lines)

### Package status: *out of date*

These stubs may be out of date. In typeshed's CI, [stubtest][] tests these stubs against an older version of the runtime package than the latest that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 3 unique allowlist entries for `auth0-python` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `auth0-python`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1,143
    - Unannotated parameters: 14
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 146
- Returns:
    - Annotated returns: 376
    - Unannotated returns: 119
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 301
- Variables:
    - Annotated variables: 187
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 92
- Class definitions:
    - Total class definitions: 63
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `aws-xray-sdk`

### Upstream repo URL

[https://github.com/aws/aws-xray-sdk-python](https://github.com/aws/aws-xray-sdk-python)

### Stub distribution name

`types-aws-xray-sdk`

### Version

The latest version of `types-aws-xray-sdk` aims to provide accurate annotations for `aws-xray-sdk==2.15.*`.

### Number of lines

976 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 31 unique allowlist entries for `aws-xray-sdk` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `aws-xray-sdk`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 258
    - Unannotated parameters: 169
    - Explicit `Any` parameters: 9
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 15
- Returns:
    - Annotated returns: 295
    - Unannotated returns: 36
    - Explicit `Any` returns: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 8
- Variables:
    - Annotated variables: 191
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 8
- Class definitions:
    - Total class definitions: 69
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `binaryornot`

### Upstream repo URL

[https://github.com/binaryornot/binaryornot](https://github.com/binaryornot/binaryornot)

### Stub distribution name

`types-binaryornot`

### Version

The latest version of `types-binaryornot` aims to provide accurate annotations for `binaryornot==0.4.*`.

### Number of lines

10 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `binaryornot` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `binaryornot`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 5
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 4
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 3
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `bleach`

### Upstream repo URL

[https://github.com/mozilla/bleach](https://github.com/mozilla/bleach)

### Stub distribution name

`types-bleach`

### Version

The latest version of `types-bleach` aims to provide accurate annotations for `bleach==6.3.*`.

### Number of lines

243 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 3 unique allowlist entries for `bleach` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `bleach`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 91
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 50
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 60
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 13
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `boltons`

### Upstream repo URL

[https://github.com/mahmoud/boltons](https://github.com/mahmoud/boltons)

### Stub distribution name

`types-boltons`

### Version

The latest version of `types-boltons` aims to provide accurate annotations for `boltons==25.0.*`.

### Number of lines

1,359 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 unique allowlist entries for `boltons` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `boltons`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 610
    - Unannotated parameters: 335
    - Explicit `Any` parameters: 60
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 8
- Returns:
    - Annotated returns: 478
    - Unannotated returns: 170
    - Explicit `Any` returns: 16
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 8
- Variables:
    - Annotated variables: 233
    - Explicit `Any` variables: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 68
- Class definitions:
    - Total class definitions: 83
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 3

---

## Info on typeshed's stubs for `braintree`

### Upstream repo URL

[https://github.com/braintree/braintree_python](https://github.com/braintree/braintree_python)

### Stub distribution name

`types-braintree`

### Version

The latest version of `types-braintree` aims to provide accurate annotations for `braintree==4.41.*`.

### Number of lines

3,556 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `braintree` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `braintree`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 308
    - Unannotated parameters: 314
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 37
- Returns:
    - Annotated returns: 445
    - Unannotated returns: 118
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 14
- Variables:
    - Annotated variables: 1,519
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 115
- Class definitions:
    - Total class definitions: 299
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `cachetools`

### Upstream repo URL

[https://github.com/tkem/cachetools](https://github.com/tkem/cachetools)

### Stub distribution name

`types-cachetools`

### Version

The latest version of `types-cachetools` aims to provide accurate annotations for `cachetools==6.2.*`.

### Number of lines

193 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 17 unique allowlist entries for `cachetools` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `cachetools`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 125
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 14
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 65
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 12
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 14
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `capturer`

### Upstream repo URL

[https://github.com/xolox/python-capturer](https://github.com/xolox/python-capturer)

### Stub distribution name

`types-capturer`

### Version

The latest version of `types-capturer` aims to provide accurate annotations for `capturer==3.0.*`.

### Number of lines

114 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `capturer` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `capturer`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 50
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 42
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 38
    - Explicit `Any` variables: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 6
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `cffi`

### Upstream repo URL

[https://github.com/python-cffi/cffi/](https://github.com/python-cffi/cffi/)

### Stub distribution name

`types-cffi`

### Version

The latest version of `types-cffi` aims to provide accurate annotations for `cffi==1.17.*`.

### Number of lines

850 (excluding blank lines)

### Package status: *out of date*

These stubs may be out of date. In typeshed's CI, [stubtest][] tests these stubs against an older version of the runtime package than the latest that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` and `win32`.

Typeshed currently has 4 unique allowlist entries for `cffi` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `cffi`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 336
    - Unannotated parameters: 212
    - Explicit `Any` parameters: 33
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 239
    - Unannotated returns: 86
    - Explicit `Any` returns: 8
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 254
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 75
- Class definitions:
    - Total class definitions: 52
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `channels`

### Upstream repo URL

[https://github.com/django/channels](https://github.com/django/channels)

### Stub distribution name

`types-channels`

### Version

The latest version of `types-channels` aims to provide accurate annotations for `channels==4.3.*`.

### Number of lines

545 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 7 unique allowlist entries for `channels` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `channels`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 239
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 36
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 151
    - Unannotated returns: 0
    - Explicit `Any` returns: 13
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 102
    - Explicit `Any` variables: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 47
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `chevron`

### Upstream repo URL

[https://github.com/noahmorrison/chevron](https://github.com/noahmorrison/chevron)

### Stub distribution name

`types-chevron`

### Version

The latest version of `types-chevron` aims to provide accurate annotations for `chevron==0.14.*`.

### Number of lines

38 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `chevron` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `chevron`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 29
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 9
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 3
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `click-default-group`

### Upstream repo URL

[https://github.com/click-contrib/click-default-group](https://github.com/click-contrib/click-default-group)

### Stub distribution name

`types-click-default-group`

### Version

The latest version of `types-click-default-group` aims to provide accurate annotations for `click-default-group==1.2.*`.

### Number of lines

79 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `click-default-group` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `click-default-group`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 52
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 14
    - Unannotated returns: 0
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 7
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 2
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `click-log`

### Upstream repo URL

[https://github.com/click-contrib/click-log](https://github.com/click-contrib/click-log)

### Stub distribution name

`types-click-log`

### Version

The latest version of `types-click-log` aims to provide accurate annotations for `click-log==0.4.*`.

### Number of lines

22 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `click-log` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `click-log`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 6
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 4
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 6
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 2
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `click-shell`

### Upstream repo URL

[https://github.com/clarkperkins/click-shell](https://github.com/clarkperkins/click-shell)

### Stub distribution name

`types-click-shell`

### Version

The latest version of `types-click-shell` aims to provide accurate annotations for `click-shell==2.1`.

### Number of lines

71 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `click-shell` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `click-shell`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 40
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 23
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 4
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 3
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `click-spinner`

### Upstream repo URL

[https://github.com/click-contrib/click-spinner](https://github.com/click-contrib/click-spinner)

### Stub distribution name

`types-click-spinner`

### Version

The latest version of `types-click-spinner` aims to provide accurate annotations for `click-spinner==0.1.*`.

### Number of lines

37 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `click-spinner` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `click-spinner`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 12
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 11
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 13
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 3
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `click-web`

### Upstream repo URL

[https://github.com/fredrik-corneliusson/click-web](https://github.com/fredrik-corneliusson/click-web)

### Stub distribution name

`types-click-web`

### Version

The latest version of `types-click-web` aims to provide accurate annotations for `click-web==0.8.*`.

### Number of lines

189 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `click-web` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `click-web`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 68
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 60
    - Unannotated returns: 0
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 55
    - Explicit `Any` variables: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1
- Class definitions:
    - Total class definitions: 29
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `colorama`

### Upstream repo URL

[https://github.com/tartley/colorama](https://github.com/tartley/colorama)

### Stub distribution name

`types-colorama`

### Version

The latest version of `types-colorama` aims to provide accurate annotations for `colorama==0.4.*`.

### Number of lines

201 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` and `win32`.

Typeshed currently has 44 unique allowlist entries for `colorama` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `colorama`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 89
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 60
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 85
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 11
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `colorful`

### Upstream repo URL

[https://github.com/timofurrer/colorful](https://github.com/timofurrer/colorful)

### Stub distribution name

`types-colorful`

### Version

The latest version of `types-colorful` aims to provide accurate annotations for `colorful==0.5.*`.

### Number of lines

128 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `colorful` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `colorful`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 73
    - Unannotated parameters: 1
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 49
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 40
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 6
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `console-menu`

### Upstream repo URL

[https://github.com/aegirhall/console-menu](https://github.com/aegirhall/console-menu)

### Stub distribution name

`types-console-menu`

### Version

The latest version of `types-console-menu` aims to provide accurate annotations for `console-menu==0.8.*`.

### Number of lines

736 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `console-menu` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `console-menu`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 217
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 278
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 58
    - Explicit `Any` variables: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1
- Class definitions:
    - Total class definitions: 39
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `convertdate`

### Upstream repo URL

[https://github.com/fitnr/convertdate](https://github.com/fitnr/convertdate)

### Stub distribution name

`types-convertdate`

### Version

The latest version of `types-convertdate` aims to provide accurate annotations for `convertdate==2.4.*`.

### Number of lines

558 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `convertdate` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `convertdate`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 486
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 266
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 135
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 2
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `croniter`

### Upstream repo URL

[https://github.com/pallets-eco/croniter](https://github.com/pallets-eco/croniter)

### Stub distribution name

`types-croniter`

### Version

The latest version of `types-croniter` aims to provide accurate annotations for `croniter==6.0.0`.

### Number of lines

358 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `croniter` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `croniter`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 164
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 42
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 48
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 9
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `dateparser`

### Upstream repo URL

[https://github.com/scrapinghub/dateparser](https://github.com/scrapinghub/dateparser)

### Stub distribution name

`types-dateparser`

### Version

The latest version of `types-dateparser` aims to provide accurate annotations for `dateparser~=1.2.2`.

### Number of lines

509 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 6 unique allowlist entries for `dateparser` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `dateparser`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 163
    - Unannotated parameters: 102
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 3
- Returns:
    - Annotated returns: 111
    - Unannotated returns: 38
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 3
- Variables:
    - Annotated variables: 137
    - Explicit `Any` variables: 29
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 3
- Class definitions:
    - Total class definitions: 34
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `decorator`

### Upstream repo URL

[https://github.com/micheles/decorator](https://github.com/micheles/decorator)

### Stub distribution name

`types-decorator`

### Version

The latest version of `types-decorator` aims to provide accurate annotations for `decorator==5.2.*`.

### Number of lines

67 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 5 unique allowlist entries for `decorator` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `decorator`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 40
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 21
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 13
    - Unannotated returns: 0
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 16
    - Explicit `Any` variables: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 2
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `defusedxml`

### Upstream repo URL

[https://github.com/tiran/defusedxml](https://github.com/tiran/defusedxml)

### Stub distribution name

`types-defusedxml`

### Version

The latest version of `types-defusedxml` aims to provide accurate annotations for `defusedxml==0.7.*`.

### Number of lines

352 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `defusedxml` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `defusedxml`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 202
    - Unannotated parameters: 20
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 50
    - Unannotated returns: 13
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 42
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 3
- Class definitions:
    - Total class definitions: 15
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `dirhash`

### Upstream repo URL

[https://github.com/andhus/dirhash-python](https://github.com/andhus/dirhash-python)

### Stub distribution name

`types-dirhash`

### Version

The latest version of `types-dirhash` aims to provide accurate annotations for `dirhash==0.5.*`.

### Number of lines

88 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `dirhash` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `dirhash`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 39
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 13
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 12
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 3
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `django-filter`

### Upstream repo URL

[https://github.com/carltongibson/django-filter/](https://github.com/carltongibson/django-filter/)

### Stub distribution name

`types-django-filter`

### Version

The latest version of `types-django-filter` aims to provide accurate annotations for `django-filter==25.2.*`.

### Number of lines

805 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 12 unique allowlist entries for `django-filter` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `django-filter`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 298
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 121
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 128
    - Unannotated returns: 0
    - Explicit `Any` returns: 43
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 113
    - Explicit `Any` variables: 25
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 73
    - Class definitions with `Any`: 3
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `django-import-export`

### Upstream repo URL

[https://github.com/django-import-export/django-import-export](https://github.com/django-import-export/django-import-export)

### Stub distribution name

`types-django-import-export`

### Version

The latest version of `types-django-import-export` aims to provide accurate annotations for `django-import-export==4.4.*`.

### Number of lines

696 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *skipped*

Stubtest is skipped in typeshed's CI for this package.

Typeshed currently has 0 allowlist entries for `django-import-export` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `django-import-export`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 376
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 135
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 255
    - Unannotated returns: 0
    - Explicit `Any` returns: 35
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 156
    - Explicit `Any` variables: 10
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 72
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `docker`

### Upstream repo URL

[https://github.com/docker/docker-py](https://github.com/docker/docker-py)

### Stub distribution name

`types-docker`

### Version

The latest version of `types-docker` aims to provide accurate annotations for `docker==7.1.*`.

### Number of lines

2,634 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 9 unique allowlist entries for `docker` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `docker`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1,296
    - Unannotated parameters: 298
    - Explicit `Any` parameters: 33
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 48
- Returns:
    - Annotated returns: 452
    - Unannotated returns: 138
    - Explicit `Any` returns: 30
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 18
- Variables:
    - Annotated variables: 224
    - Explicit `Any` variables: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 4
- Class definitions:
    - Total class definitions: 139
    - Class definitions with `Any`: 2
    - Class definitions marked as at least partially `Incomplete`: 24

---

## Info on typeshed's stubs for `dockerfile-parse`

### Upstream repo URL

[https://github.com/containerbuildsystem/dockerfile-parse](https://github.com/containerbuildsystem/dockerfile-parse)

### Stub distribution name

`types-dockerfile-parse`

### Version

The latest version of `types-dockerfile-parse` aims to provide accurate annotations for `dockerfile-parse==2.0.*`.

### Number of lines

116 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `dockerfile-parse` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `dockerfile-parse`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 46
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 24
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 39
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 8
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `docutils`

### Upstream repo URL

[https://sourceforge.net/p/docutils/code](https://sourceforge.net/p/docutils/code)

### Stub distribution name

`types-docutils`

### Version

The latest version of `types-docutils` aims to provide accurate annotations for `docutils==0.22.3`.

### Number of lines

5,665 (excluding blank lines)

### Package status: *out of date*

These stubs may be out of date. In typeshed's CI, [stubtest][] tests these stubs against an older version of the runtime package than the latest that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 18 unique allowlist entries for `docutils` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `docutils`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 2,440
    - Unannotated parameters: 708
    - Explicit `Any` parameters: 39
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 16
- Returns:
    - Annotated returns: 2,109
    - Unannotated returns: 323
    - Explicit `Any` returns: 219
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 7
- Variables:
    - Annotated variables: 1,508
    - Explicit `Any` variables: 23
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 234
- Class definitions:
    - Total class definitions: 499
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `editdistance`

### Upstream repo URL

[https://github.com/roy-ht/editdistance](https://github.com/roy-ht/editdistance)

### Stub distribution name

`types-editdistance`

### Version

The latest version of `types-editdistance` aims to provide accurate annotations for `editdistance==0.8.*`.

### Number of lines

6 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `editdistance` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `editdistance`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 10
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 4
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `entrypoints`

### Upstream repo URL

[https://github.com/takluyver/entrypoints](https://github.com/takluyver/entrypoints)

### Stub distribution name

`types-entrypoints`

### Version

The latest version of `types-entrypoints` aims to provide accurate annotations for `entrypoints==0.4.*`.

### Number of lines

41 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `entrypoints` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `entrypoints`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 23
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 12
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 12
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 5
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `ephem`

### Upstream repo URL

[https://github.com/brandon-rhodes/pyephem](https://github.com/brandon-rhodes/pyephem)

### Stub distribution name

`types-ephem`

### Version

The latest version of `types-ephem` aims to provide accurate annotations for `ephem==4.2.*`.

### Number of lines

591 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 6 unique allowlist entries for `ephem` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `ephem`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 182
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 187
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 150
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 55
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `et_xmlfile`

### Upstream repo URL

[https://foss.heptapod.net/openpyxl/et_xmlfile](https://foss.heptapod.net/openpyxl/et_xmlfile)

### Stub distribution name

`types-et_xmlfile`

### Version

The latest version of `types-et_xmlfile` aims to provide accurate annotations for `et_xmlfile==2.0.*`.

### Number of lines

208 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `et_xmlfile` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `et_xmlfile`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 133
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 12
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 21
    - Unannotated returns: 0
    - Explicit `Any` returns: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 9
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1
- Class definitions:
    - Total class definitions: 4
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `fanstatic`

### Upstream repo URL

[https://github.com/zopefoundation/fanstatic](https://github.com/zopefoundation/fanstatic)

### Stub distribution name

`types-fanstatic`

### Version

The latest version of `types-fanstatic` aims to provide accurate annotations for `fanstatic==1.6.*`.

### Number of lines

537 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 40 unique allowlist entries for `fanstatic` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `fanstatic`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 167
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 8
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 134
    - Unannotated returns: 0
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 128
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 50
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `first`

### Upstream repo URL

[https://github.com/hynek/first](https://github.com/hynek/first)

### Stub distribution name

`types-first`

### Version

The latest version of `types-first` aims to provide accurate annotations for `first==2.0.*`.

### Number of lines

16 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `first` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `first`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 11
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 5
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 2
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `flake8`

### Upstream repo URL

[https://github.com/pycqa/flake8](https://github.com/pycqa/flake8)

### Stub distribution name

`types-flake8`

### Version

The latest version of `types-flake8` aims to provide accurate annotations for `flake8==7.3.*`.

### Number of lines

574 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `flake8` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `flake8`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 223
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 35
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 165
    - Unannotated returns: 0
    - Explicit `Any` returns: 8
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 185
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 90
- Class definitions:
    - Total class definitions: 39
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `flake8-bugbear`

### Upstream repo URL

[https://github.com/PyCQA/flake8-bugbear](https://github.com/PyCQA/flake8-bugbear)

### Stub distribution name

`types-flake8-bugbear`

### Version

The latest version of `types-flake8-bugbear` aims to provide accurate annotations for `flake8-bugbear==25.11.29`.

### Number of lines

246 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 31 unique allowlist entries for `flake8-bugbear` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `flake8-bugbear`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 139
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 124
    - Unannotated returns: 0
    - Explicit `Any` returns: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 2
- Variables:
    - Annotated variables: 58
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 15
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `flake8-builtins`

### Upstream repo URL

[https://github.com/gforcada/flake8-builtins](https://github.com/gforcada/flake8-builtins)

### Stub distribution name

`types-flake8-builtins`

### Version

The latest version of `types-flake8-builtins` aims to provide accurate annotations for `flake8-builtins==3.1.*`.

### Number of lines

40 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `flake8-builtins` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `flake8-builtins`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 17
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 15
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 13
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `flake8-docstrings`

### Upstream repo URL

[https://github.com/pycqa/flake8-docstrings](https://github.com/pycqa/flake8-docstrings)

### Stub distribution name

`types-flake8-docstrings`

### Version

The latest version of `types-flake8-docstrings` aims to provide accurate annotations for `flake8-docstrings==1.7.*`.

### Number of lines

21 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `flake8-docstrings` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `flake8-docstrings`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 5
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 4
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 7
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `flake8-rst-docstrings`

### Upstream repo URL

[https://github.com/peterjc/flake8-rst-docstrings](https://github.com/peterjc/flake8-rst-docstrings)

### Stub distribution name

`types-flake8-rst-docstrings`

### Version

The latest version of `types-flake8-rst-docstrings` aims to provide accurate annotations for `flake8-rst-docstrings==0.4.*`.

### Number of lines

31 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `flake8-rst-docstrings` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `flake8-rst-docstrings`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 10
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 5
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 12
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `flake8-simplify`

### Upstream repo URL

[https://github.com/MartinThoma/flake8-simplify](https://github.com/MartinThoma/flake8-simplify)

### Stub distribution name

`types-flake8-simplify`

### Version

The latest version of `types-flake8-simplify` aims to provide accurate annotations for `flake8-simplify==0.30.*`.

### Number of lines

121 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `flake8-simplify` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `flake8-simplify`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 75
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 72
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 15
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 2
- Class definitions:
    - Total class definitions: 7
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `flake8-typing-imports`

### Upstream repo URL

[https://github.com/asottile/flake8-typing-imports](https://github.com/asottile/flake8-typing-imports)

### Stub distribution name

`types-flake8-typing-imports`

### Version

The latest version of `types-flake8-typing-imports` aims to provide accurate annotations for `flake8-typing-imports==1.17.*`.

### Number of lines

36 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `flake8-typing-imports` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `flake8-typing-imports`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 11
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 13
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 12
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 3
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `fpdf2`

### Upstream repo URL

[https://github.com/PyFPDF/fpdf2](https://github.com/PyFPDF/fpdf2)

### Stub distribution name

`types-fpdf2`

### Version

The latest version of `types-fpdf2` aims to provide accurate annotations for `fpdf2==2.8.4`.

### Number of lines

3,851 (excluding blank lines)

### Package status: *out of date*

These stubs may be out of date. In typeshed's CI, [stubtest][] tests these stubs against an older version of the runtime package than the latest that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 6 unique allowlist entries for `fpdf2` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `fpdf2`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1,271
    - Unannotated parameters: 569
    - Explicit `Any` parameters: 9
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 13
- Returns:
    - Annotated returns: 729
    - Unannotated returns: 150
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 9
- Variables:
    - Annotated variables: 791
    - Explicit `Any` variables: 13
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 171
- Class definitions:
    - Total class definitions: 236
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 1

---

## Info on typeshed's stubs for `gdb`

### Extra description

Type hints for GDB's [Python API](https://sourceware.org/gdb/onlinedocs/gdb/Python-API.html). Note that this API is available only when running Python scripts under GDB: it is not possible to install the `gdb` package separately, for instance using `pip`.

### Upstream repo URL

[https://sourceware.org/git/gitweb.cgi?p=binutils-gdb.git;a=tree](https://sourceware.org/git/gitweb.cgi?p=binutils-gdb.git;a=tree)

### Stub distribution name

`types-gdb`

### Version

The latest version of `types-gdb` aims to provide accurate annotations for `gdb==16.3.*`.

### Number of lines

1,588 (excluding blank lines)

### Package status: *not on pypi*

The runtime package that these stubs are for doesn't exist on PyPI, so whether or not these stubs are up to date or not is unknown.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *skipped*

Stubtest is skipped in typeshed's CI for this package.

Typeshed currently has 52 unique allowlist entries for `gdb` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `gdb`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 515
    - Unannotated parameters: 15
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 421
    - Unannotated returns: 26
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 489
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 2
- Class definitions:
    - Total class definitions: 154
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `geopandas`

### Upstream repo URL

[https://github.com/geopandas/geopandas](https://github.com/geopandas/geopandas)

### Stub distribution name

`types-geopandas`

### Version

The latest version of `types-geopandas` aims to provide accurate annotations for `geopandas==1.1.2`.

### Number of lines

1,839 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 13 unique allowlist entries for `geopandas` when running stubtest in CI.

### Pyright settings in CI: *entirely excluded*

All files in this stubs package are excluded from the pyright check in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `geopandas`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1,022
    - Unannotated parameters: 69
    - Explicit `Any` parameters: 31
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 42
- Returns:
    - Annotated returns: 424
    - Unannotated returns: 6
    - Explicit `Any` returns: 11
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 4
- Variables:
    - Annotated variables: 33
    - Explicit `Any` variables: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 23
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `gevent`

### Upstream repo URL

[https://github.com/gevent/gevent](https://github.com/gevent/gevent)

### Stub distribution name

`types-gevent`

### Version

The latest version of `types-gevent` aims to provide accurate annotations for `gevent==25.9.*`.

### Number of lines

3,234 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `darwin`, `linux` and `win32`.

Typeshed currently has 145 unique allowlist entries for `gevent` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `gevent`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1,367
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 68
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 842
    - Unannotated returns: 0
    - Explicit `Any` returns: 20
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 371
    - Explicit `Any` variables: 26
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 210
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `google-cloud-ndb`

### Upstream repo URL

[https://github.com/googleapis/python-ndb](https://github.com/googleapis/python-ndb)

### Stub distribution name

`types-google-cloud-ndb`

### Version

The latest version of `types-google-cloud-ndb` aims to provide accurate annotations for `google-cloud-ndb==2.4.*`.

### Number of lines

1,531 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 3 unique allowlist entries for `google-cloud-ndb` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `google-cloud-ndb`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 484
    - Unannotated parameters: 370
    - Explicit `Any` parameters: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 123
- Returns:
    - Annotated returns: 236
    - Unannotated returns: 203
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 194
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 134
- Class definitions:
    - Total class definitions: 143
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `greenlet`

### Upstream repo URL

[https://github.com/python-greenlet/greenlet](https://github.com/python-greenlet/greenlet)

### Stub distribution name

`types-greenlet`

### Version

The latest version of `types-greenlet` aims to provide accurate annotations for `greenlet==3.3.*`.

### Number of lines

86 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 unique allowlist entries for `greenlet` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `greenlet`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 21
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 25
    - Unannotated returns: 0
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 12
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 5
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `grpcio`

### Upstream repo URL

[https://github.com/grpc/grpc](https://github.com/grpc/grpc)

### Stub distribution name

`types-grpcio`

### Version

The latest version of `types-grpcio` aims to provide accurate annotations for `grpcio==1.*`.

### Number of lines

926 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 3 unique allowlist entries for `grpcio` when running stubtest in CI.

### Pyright settings in CI: *strict on some files*

Some files in this stubs package are tested with the stricter pyright settings in typeshed's CI; some are excluded from the stricter settings.

### Statistics on the annotations in typeshed's stubs for `grpcio`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 310
    - Unannotated parameters: 4
    - Explicit `Any` parameters: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 208
    - Unannotated returns: 1
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 29
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 68
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `grpcio-channelz`

### Upstream repo URL

[https://github.com/grpc/grpc](https://github.com/grpc/grpc)

### Stub distribution name

`types-grpcio-channelz`

### Version

The latest version of `types-grpcio-channelz` aims to provide accurate annotations for `grpcio-channelz==1.*`.

### Number of lines

724 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `grpcio-channelz` when running stubtest in CI.

### Pyright settings in CI: *strict on some files*

Some files in this stubs package are tested with the stricter pyright settings in typeshed's CI; some are excluded from the stricter settings.

### Statistics on the annotations in typeshed's stubs for `grpcio-channelz`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 156
    - Unannotated parameters: 94
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 54
- Returns:
    - Annotated returns: 55
    - Unannotated returns: 15
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 324
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 21
- Class definitions:
    - Total class definitions: 44
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `grpcio-health-checking`

### Upstream repo URL

[https://github.com/grpc/grpc](https://github.com/grpc/grpc)

### Stub distribution name

`types-grpcio-health-checking`

### Version

The latest version of `types-grpcio-health-checking` aims to provide accurate annotations for `grpcio-health-checking==1.*`.

### Number of lines

89 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `grpcio-health-checking` when running stubtest in CI.

### Pyright settings in CI: *strict on some files*

Some files in this stubs package are tested with the stricter pyright settings in typeshed's CI; some are excluded from the stricter settings.

### Statistics on the annotations in typeshed's stubs for `grpcio-health-checking`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 15
    - Unannotated parameters: 27
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 2
- Returns:
    - Annotated returns: 16
    - Unannotated returns: 4
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 16
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 6
- Class definitions:
    - Total class definitions: 7
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `grpcio-reflection`

### Upstream repo URL

[https://github.com/grpc/grpc](https://github.com/grpc/grpc)

### Stub distribution name

`types-grpcio-reflection`

### Version

The latest version of `types-grpcio-reflection` aims to provide accurate annotations for `grpcio-reflection==1.*`.

### Number of lines

165 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `grpcio-reflection` when running stubtest in CI.

### Pyright settings in CI: *strict on some files*

Some files in this stubs package are tested with the stricter pyright settings in typeshed's CI; some are excluded from the stricter settings.

### Statistics on the annotations in typeshed's stubs for `grpcio-reflection`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 34
    - Unannotated parameters: 17
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 7
- Returns:
    - Annotated returns: 18
    - Unannotated returns: 4
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 55
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1
- Class definitions:
    - Total class definitions: 15
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `grpcio-status`

### Upstream repo URL

[https://github.com/grpc/grpc](https://github.com/grpc/grpc)

### Stub distribution name

`types-grpcio-status`

### Version

The latest version of `types-grpcio-status` aims to provide accurate annotations for `grpcio-status==1.*`.

### Number of lines

10 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `grpcio-status` when running stubtest in CI.

### Pyright settings in CI: *strict on some files*

Some files in this stubs package are tested with the stricter pyright settings in typeshed's CI; some are excluded from the stricter settings.

### Statistics on the annotations in typeshed's stubs for `grpcio-status`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1
    - Unannotated parameters: 2
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 1
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `gunicorn`

### Upstream repo URL

[https://github.com/benoitc/gunicorn](https://github.com/benoitc/gunicorn)

### Stub distribution name

`types-gunicorn`

### Version

The latest version of `types-gunicorn` aims to provide accurate annotations for `gunicorn==23.0.*`.

### Number of lines

1,903 (excluding blank lines)

### Package status: *out of date*

These stubs may be out of date. In typeshed's CI, [stubtest][] tests these stubs against an older version of the runtime package than the latest that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `darwin` and `linux`.

Typeshed currently has 2 unique allowlist entries for `gunicorn` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `gunicorn`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 479
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 11
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 382
    - Unannotated returns: 0
    - Explicit `Any` returns: 11
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 922
    - Explicit `Any` variables: 21
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 164
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `hdbcli`

### Stub distribution name

`types-hdbcli`

### Version

The latest version of `types-hdbcli` aims to provide accurate annotations for `hdbcli==2.25.*`.

### Number of lines

147 (excluding blank lines)

### Package status: *out of date*

These stubs may be out of date. In typeshed's CI, [stubtest][] tests these stubs against an older version of the runtime package than the latest that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 8 unique allowlist entries for `hdbcli` when running stubtest in CI.

### Pyright settings in CI: *strict on some files*

Some files in this stubs package are tested with the stricter pyright settings in typeshed's CI; some are excluded from the stricter settings.

### Statistics on the annotations in typeshed's stubs for `hdbcli`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 78
    - Unannotated parameters: 4
    - Explicit `Any` parameters: 13
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 65
    - Unannotated returns: 3
    - Explicit `Any` returns: 10
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 21
    - Explicit `Any` variables: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1
- Class definitions:
    - Total class definitions: 16
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `hnswlib`

### Upstream repo URL

[https://github.com/nmslib/hnswlib](https://github.com/nmslib/hnswlib)

### Stub distribution name

`types-hnswlib`

### Version

The latest version of `types-hnswlib` aims to provide accurate annotations for `hnswlib==0.8.*`.

### Number of lines

60 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `hnswlib` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `hnswlib`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 32
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 26
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 3
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `html5lib`

### Upstream repo URL

[https://github.com/html5lib/html5lib-python](https://github.com/html5lib/html5lib-python)

### Stub distribution name

`types-html5lib`

### Version

The latest version of `types-html5lib` aims to provide accurate annotations for `html5lib==1.1.*`.

### Number of lines

850 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 5 unique allowlist entries for `html5lib` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `html5lib`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 204
    - Unannotated parameters: 128
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 6
- Returns:
    - Annotated returns: 252
    - Unannotated returns: 60
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 6
- Variables:
    - Annotated variables: 246
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 68
- Class definitions:
    - Total class definitions: 42
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 9

---

## Info on typeshed's stubs for `httplib2`

### Upstream repo URL

[https://github.com/httplib2/httplib2](https://github.com/httplib2/httplib2)

### Stub distribution name

`types-httplib2`

### Version

The latest version of `types-httplib2` aims to provide accurate annotations for `httplib2==0.31.2`.

### Number of lines

242 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `httplib2` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `httplib2`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 39
    - Unannotated parameters: 116
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 1
- Returns:
    - Annotated returns: 54
    - Unannotated returns: 7
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 94
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 34
- Class definitions:
    - Total class definitions: 26
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `hvac`

### Upstream repo URL

[https://github.com/hvac/hvac](https://github.com/hvac/hvac)

### Stub distribution name

`types-hvac`

### Version

The latest version of `types-hvac` aims to provide accurate annotations for `hvac==2.4.*`.

### Number of lines

1,825 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `hvac` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `hvac`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 511
    - Unannotated parameters: 1,222
    - Explicit `Any` parameters: 23
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 1
- Returns:
    - Annotated returns: 82
    - Unannotated returns: 491
    - Explicit `Any` returns: 19
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 94
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 75
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `ibm-db`

### Upstream repo URL

[https://github.com/ibmdb/python-ibmdb](https://github.com/ibmdb/python-ibmdb)

### Stub distribution name

`types-ibm-db`

### Version

The latest version of `types-ibm-db` aims to provide accurate annotations for `ibm-db==3.2.6`.

### Number of lines

346 (excluding blank lines)

### Package status: *out of date*

These stubs may be out of date. In typeshed's CI, [stubtest][] tests these stubs against an older version of the runtime package than the latest that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `ibm-db` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `ibm-db`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 168
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 70
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 202
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 4
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `icalendar`

### Upstream repo URL

[https://github.com/collective/icalendar](https://github.com/collective/icalendar)

### Stub distribution name

`types-icalendar`

### Version

The latest version of `types-icalendar` aims to provide accurate annotations for `icalendar==6.3.2`.

### Number of lines

1,338 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 6 unique allowlist entries for `icalendar` when running stubtest in CI.

### Pyright settings in CI: *strict on some files*

Some files in this stubs package are tested with the stricter pyright settings in typeshed's CI; some are excluded from the stricter settings.

### Statistics on the annotations in typeshed's stubs for `icalendar`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 364
    - Unannotated parameters: 3
    - Explicit `Any` parameters: 9
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 3
- Returns:
    - Annotated returns: 422
    - Unannotated returns: 0
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 3
- Variables:
    - Annotated variables: 152
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 2
- Class definitions:
    - Total class definitions: 65
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 2

---

## Info on typeshed's stubs for `inifile`

### Upstream repo URL

[https://github.com/mitsuhiko/python-inifile](https://github.com/mitsuhiko/python-inifile)

### Stub distribution name

`types-inifile`

### Version

The latest version of `types-inifile` aims to provide accurate annotations for `inifile==0.4.*`.

### Number of lines

124 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 20 unique allowlist entries for `inifile` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `inifile`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 60
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 59
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 4
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `jmespath`

### Upstream repo URL

[https://github.com/jmespath/jmespath.py](https://github.com/jmespath/jmespath.py)

### Stub distribution name

`types-jmespath`

### Version

The latest version of `types-jmespath` aims to provide accurate annotations for `jmespath==1.1.*`.

### Number of lines

214 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `jmespath` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `jmespath`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 133
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 30
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 74
    - Unannotated returns: 0
    - Explicit `Any` returns: 23
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 49
    - Explicit `Any` variables: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 23
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `jsonnet`

### Upstream repo URL

[https://github.com/google/jsonnet](https://github.com/google/jsonnet)

### Stub distribution name

`types-jsonnet`

### Version

The latest version of `types-jsonnet` aims to provide accurate annotations for `jsonnet==0.21.*`.

### Number of lines

33 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `jsonnet` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `jsonnet`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 25
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `jsonschema`

### Upstream repo URL

[https://github.com/python-jsonschema/jsonschema](https://github.com/python-jsonschema/jsonschema)

### Stub distribution name

`types-jsonschema`

### Version

The latest version of `types-jsonschema` aims to provide accurate annotations for `jsonschema~=4.26.0`.

### Number of lines

484 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 45 unique allowlist entries for `jsonschema` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `jsonschema`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 173
    - Unannotated parameters: 257
    - Explicit `Any` parameters: 9
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 9
- Returns:
    - Annotated returns: 175
    - Unannotated returns: 11
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 10
- Variables:
    - Annotated variables: 58
    - Explicit `Any` variables: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 14
- Class definitions:
    - Total class definitions: 26
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `jwcrypto`

### Upstream repo URL

[https://github.com/latchset/jwcrypto](https://github.com/latchset/jwcrypto)

### Stub distribution name

`types-jwcrypto`

### Version

The latest version of `types-jwcrypto` aims to provide accurate annotations for `jwcrypto==1.5.*`.

### Number of lines

472 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 4 unique allowlist entries for `jwcrypto` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `jwcrypto`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 151
    - Unannotated parameters: 31
    - Explicit `Any` parameters: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 133
    - Unannotated returns: 8
    - Explicit `Any` returns: 11
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 55
    - Explicit `Any` variables: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 3
- Class definitions:
    - Total class definitions: 40
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `keyboard`

### Upstream repo URL

[https://github.com/boppreh/keyboard](https://github.com/boppreh/keyboard)

### Stub distribution name

`types-keyboard`

### Version

The latest version of `types-keyboard` aims to provide accurate annotations for `keyboard==0.13.*`.

### Number of lines

246 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 7 unique allowlist entries for `keyboard` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `keyboard`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 130
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 76
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 38
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 7
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `ldap3`

### Upstream repo URL

[https://github.com/cannatag/ldap3](https://github.com/cannatag/ldap3)

### Stub distribution name

`types-ldap3`

### Version

The latest version of `types-ldap3` aims to provide accurate annotations for `ldap3==2.9.*`.

### Number of lines

2,494 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `ldap3` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `ldap3`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 276
    - Unannotated parameters: 936
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 219
    - Unannotated returns: 421
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 937
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 375
- Class definitions:
    - Total class definitions: 316
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `libsass`

### Upstream repo URL

[https://github.com/sass/libsass-python](https://github.com/sass/libsass-python)

### Stub distribution name

`types-libsass`

### Version

The latest version of `types-libsass` aims to provide accurate annotations for `libsass==0.23.*`.

### Number of lines

250 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 unique allowlist entries for `libsass` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `libsass`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 109
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 41
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 36
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 17
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `lunardate`

### Upstream repo URL

[https://github.com/lidaobing/python-lunardate](https://github.com/lidaobing/python-lunardate)

### Stub distribution name

`types-lunardate`

### Version

The latest version of `types-lunardate` aims to provide accurate annotations for `lunardate==0.2.*`.

### Number of lines

34 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `lunardate` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `lunardate`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 20
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 17
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 7
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `lupa`

### Upstream repo URL

[https://github.com/scoder/lupa](https://github.com/scoder/lupa)

### Stub distribution name

`types-lupa`

### Version

The latest version of `types-lupa` aims to provide accurate annotations for `lupa==2.6.*`.

### Number of lines

522 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `lupa` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `lupa`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 170
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 30
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 138
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 61
    - Explicit `Any` variables: 12
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 46
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `lzstring`

### Upstream repo URL

[https://github.com/gkovacs/lz-string-python](https://github.com/gkovacs/lz-string-python)

### Stub distribution name

`types-lzstring`

### Version

The latest version of `types-lzstring` aims to provide accurate annotations for `lzstring==1.0.*`.

### Number of lines

17 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 5 unique allowlist entries for `lzstring` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `lzstring`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 8
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 8
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `m3u8`

### Upstream repo URL

[https://github.com/globocom/m3u8](https://github.com/globocom/m3u8)

### Stub distribution name

`types-m3u8`

### Version

The latest version of `types-m3u8` aims to provide accurate annotations for `m3u8==6.0.*`.

### Number of lines

602 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 3 unique allowlist entries for `m3u8` when running stubtest in CI.

### Pyright settings in CI: *strict on some files*

Some files in this stubs package are tested with the stricter pyright settings in typeshed's CI; some are excluded from the stricter settings.

### Statistics on the annotations in typeshed's stubs for `m3u8`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 200
    - Unannotated parameters: 12
    - Explicit `Any` parameters: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 9
- Returns:
    - Annotated returns: 99
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 214
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 12
- Class definitions:
    - Total class definitions: 42
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `mock`

### Upstream repo URL

[https://github.com/testing-cabal/mock](https://github.com/testing-cabal/mock)

### Stub distribution name

`types-mock`

### Version

The latest version of `types-mock` aims to provide accurate annotations for `mock==5.2.*`.

### Number of lines

368 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 4 unique allowlist entries for `mock` when running stubtest in CI.

### Pyright settings in CI: *strict on some files*

Some files in this stubs package are tested with the stricter pyright settings in typeshed's CI; some are excluded from the stricter settings.

### Statistics on the annotations in typeshed's stubs for `mock`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 196
    - Unannotated parameters: 20
    - Explicit `Any` parameters: 86
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 25
- Returns:
    - Annotated returns: 90
    - Unannotated returns: 0
    - Explicit `Any` returns: 15
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 58
    - Explicit `Any` variables: 33
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 24
    - Class definitions with `Any`: 3
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `mypy-extensions`

### Upstream repo URL

[https://github.com/python/mypy_extensions](https://github.com/python/mypy_extensions)

### Stub distribution name

`types-mypy-extensions`

### Version

The latest version of `types-mypy-extensions` aims to provide accurate annotations for `mypy-extensions==1.1.*`.

### Number of lines

80 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 6 unique allowlist entries for `mypy-extensions` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `mypy-extensions`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 31
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 28
    - Unannotated returns: 0
    - Explicit `Any` returns: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 3
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `mysqlclient`

### Upstream repo URL

[https://github.com/PyMySQL/mysqlclient](https://github.com/PyMySQL/mysqlclient)

### Stub distribution name

`types-mysqlclient`

### Version

The latest version of `types-mysqlclient` aims to provide accurate annotations for `mysqlclient==2.2.*`.

### Number of lines

1,275 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `mysqlclient` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `mysqlclient`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 32
    - Unannotated parameters: 67
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 40
    - Unannotated returns: 76
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 971
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 28
- Class definitions:
    - Total class definitions: 35
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 1

---

## Info on typeshed's stubs for `nanoid`

### Upstream repo URL

[https://github.com/puyuan/py-nanoid](https://github.com/puyuan/py-nanoid)

### Stub distribution name

`types-nanoid`

### Version

The latest version of `types-nanoid` aims to provide accurate annotations for `nanoid==2.0.0`.

### Number of lines

16 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `nanoid` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `nanoid`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 8
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 4
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 2
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `nanoleafapi`

### Upstream repo URL

[https://github.com/MylesMor/nanoleafapi](https://github.com/MylesMor/nanoleafapi)

### Stub distribution name

`types-nanoleafapi`

### Version

The latest version of `types-nanoleafapi` aims to provide accurate annotations for `nanoleafapi==2.1.*`.

### Number of lines

91 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `nanoleafapi` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `nanoleafapi`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 33
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 2
- Returns:
    - Annotated returns: 49
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 3
- Variables:
    - Annotated variables: 16
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 5
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `netaddr`

### Upstream repo URL

[https://github.com/drkjam/netaddr](https://github.com/drkjam/netaddr)

### Stub distribution name

`types-netaddr`

### Version

The latest version of `types-netaddr` aims to provide accurate annotations for `netaddr==1.3.*`.

### Number of lines

712 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 unique allowlist entries for `netaddr` when running stubtest in CI.

### Pyright settings in CI: *strict on some files*

Some files in this stubs package are tested with the stricter pyright settings in typeshed's CI; some are excluded from the stricter settings.

### Statistics on the annotations in typeshed's stubs for `netaddr`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 291
    - Unannotated parameters: 1
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 308
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 101
    - Explicit `Any` variables: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 43
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `netifaces`

### Upstream repo URL

[https://github.com/al45tair/netifaces](https://github.com/al45tair/netifaces)

### Stub distribution name

`types-netifaces`

### Version

The latest version of `types-netifaces` aims to provide accurate annotations for `netifaces==0.11.*`.

### Number of lines

69 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 33 unique allowlist entries for `netifaces` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `netifaces`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 3
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 65
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `networkx`

### Upstream repo URL

[https://github.com/networkx/networkx](https://github.com/networkx/networkx)

### Stub distribution name

`types-networkx`

### Version

The latest version of `types-networkx` aims to provide accurate annotations for `networkx==3.6.1`.

### Number of lines

7,630 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 23 unique allowlist entries for `networkx` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `networkx`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 3,175
    - Unannotated parameters: 1,266
    - Explicit `Any` parameters: 24
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 213
- Returns:
    - Annotated returns: 1,073
    - Unannotated returns: 544
    - Explicit `Any` returns: 19
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 264
- Variables:
    - Annotated variables: 387
    - Explicit `Any` variables: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 240
- Class definitions:
    - Total class definitions: 132
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 1

---

## Info on typeshed's stubs for `oauthlib`

### Upstream repo URL

[https://github.com/oauthlib/oauthlib](https://github.com/oauthlib/oauthlib)

### Stub distribution name

`types-oauthlib`

### Version

The latest version of `types-oauthlib` aims to provide accurate annotations for `oauthlib==3.3.*`.

### Number of lines

1,884 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `oauthlib` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `oauthlib`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 753
    - Unannotated parameters: 219
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 29
- Returns:
    - Annotated returns: 314
    - Unannotated returns: 62
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 11
- Variables:
    - Annotated variables: 342
    - Explicit `Any` variables: 29
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 12
- Class definitions:
    - Total class definitions: 118
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 2

---

## Info on typeshed's stubs for `objgraph`

### Upstream repo URL

[https://github.com/mgedmin/objgraph](https://github.com/mgedmin/objgraph)

### Stub distribution name

`types-objgraph`

### Version

The latest version of `types-objgraph` aims to provide accurate annotations for `objgraph==3.6.*`.

### Number of lines

87 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `objgraph` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `objgraph`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 71
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 17
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 6
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `olefile`

### Upstream repo URL

[https://github.com/decalage2/olefile](https://github.com/decalage2/olefile)

### Stub distribution name

`types-olefile`

### Version

The latest version of `types-olefile` aims to provide accurate annotations for `olefile==0.47.*`.

### Number of lines

222 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `olefile` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `olefile`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 103
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 66
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 75
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 7
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `openpyxl`

### Upstream repo URL

[https://foss.heptapod.net/openpyxl/openpyxl](https://foss.heptapod.net/openpyxl/openpyxl)

### Stub distribution name

`types-openpyxl`

### Version

The latest version of `types-openpyxl` aims to provide accurate annotations for `openpyxl==3.1.5`.

### Number of lines

13,159 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 175 unique allowlist entries for `openpyxl` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `openpyxl`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 3,704
    - Unannotated parameters: 511
    - Explicit `Any` parameters: 13
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 12
- Returns:
    - Annotated returns: 1,312
    - Unannotated returns: 87
    - Explicit `Any` returns: 11
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 7
- Variables:
    - Annotated variables: 4,019
    - Explicit `Any` variables: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 339
- Class definitions:
    - Total class definitions: 603
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 20

---

## Info on typeshed's stubs for `opentracing`

### Upstream repo URL

[https://github.com/opentracing/opentracing-python](https://github.com/opentracing/opentracing-python)

### Stub distribution name

`types-opentracing`

### Version

The latest version of `types-opentracing` aims to provide accurate annotations for `opentracing==2.4.*`.

### Number of lines

332 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 4 unique allowlist entries for `opentracing` when running stubtest in CI.

### Pyright settings in CI: *strict on some files*

Some files in this stubs package are tested with the stricter pyright settings in typeshed's CI; some are excluded from the stricter settings.

### Statistics on the annotations in typeshed's stubs for `opentracing`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 104
    - Unannotated parameters: 1
    - Explicit `Any` parameters: 21
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 113
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 56
    - Explicit `Any` variables: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 26
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `paramiko`

### Upstream repo URL

[https://github.com/paramiko/paramiko](https://github.com/paramiko/paramiko)

### Stub distribution name

`types-paramiko`

### Version

The latest version of `types-paramiko` aims to provide accurate annotations for `paramiko==4.0.*`.

### Number of lines

1,895 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` and `win32`.

Typeshed currently has 5 unique allowlist entries for `paramiko` when running stubtest in CI.

### Pyright settings in CI: *strict on some files*

Some files in this stubs package are tested with the stricter pyright settings in typeshed's CI; some are excluded from the stricter settings.

### Statistics on the annotations in typeshed's stubs for `paramiko`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 775
    - Unannotated parameters: 8
    - Explicit `Any` parameters: 13
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 2
- Returns:
    - Annotated returns: 644
    - Unannotated returns: 3
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 559
    - Explicit `Any` variables: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 23
- Class definitions:
    - Total class definitions: 129
    - Class definitions with `Any`: 2
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `parsimonious`

### Upstream repo URL

[https://github.com/erikrose/parsimonious](https://github.com/erikrose/parsimonious)

### Stub distribution name

`types-parsimonious`

### Version

The latest version of `types-parsimonious` aims to provide accurate annotations for `parsimonious==0.11.*`.

### Number of lines

197 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 3 unique allowlist entries for `parsimonious` when running stubtest in CI.

### Pyright settings in CI: *strict on some files*

Some files in this stubs package are tested with the stricter pyright settings in typeshed's CI; some are excluded from the stricter settings.

### Statistics on the annotations in typeshed's stubs for `parsimonious`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 114
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 22
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 59
    - Unannotated returns: 1
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 34
    - Explicit `Any` variables: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 2
- Class definitions:
    - Total class definitions: 28
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `passlib`

### Upstream repo URL

[https://foss.heptapod.net/python-libs/passlib](https://foss.heptapod.net/python-libs/passlib)

### Stub distribution name

`types-passlib`

### Version

The latest version of `types-passlib` aims to provide accurate annotations for `passlib==1.7.*`.

### Number of lines

2,056 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 32 unique allowlist entries for `passlib` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `passlib`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 470
    - Unannotated parameters: 453
    - Explicit `Any` parameters: 32
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 2
- Returns:
    - Annotated returns: 291
    - Unannotated returns: 207
    - Explicit `Any` returns: 13
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 579
    - Explicit `Any` variables: 54
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 8
- Class definitions:
    - Total class definitions: 143
    - Class definitions with `Any`: 2
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `passpy`

### Upstream repo URL

[https://github.com/bfrascher/passpy](https://github.com/bfrascher/passpy)

### Stub distribution name

`types-passpy`

### Version

The latest version of `types-passpy` aims to provide accurate annotations for `passpy==1.0.*`.

### Number of lines

47 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 3 unique allowlist entries for `passpy` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `passpy`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 43
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 20
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 3
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `peewee`

### Upstream repo URL

[https://github.com/coleifer/peewee](https://github.com/coleifer/peewee)

### Stub distribution name

`types-peewee`

### Version

The latest version of `types-peewee` aims to provide accurate annotations for `peewee==3.19.0`.

### Number of lines

1,758 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 20 unique allowlist entries for `peewee` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `peewee`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 416
    - Unannotated parameters: 681
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 202
- Returns:
    - Annotated returns: 363
    - Unannotated returns: 423
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 5
- Variables:
    - Annotated variables: 403
    - Explicit `Any` variables: 31
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 319
- Class definitions:
    - Total class definitions: 169
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pep8-naming`

### Upstream repo URL

[https://github.com/PyCQA/pep8-naming](https://github.com/PyCQA/pep8-naming)

### Stub distribution name

`types-pep8-naming`

### Version

The latest version of `types-pep8-naming` aims to provide accurate annotations for `pep8-naming==0.15.*`.

### Number of lines

150 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `pep8-naming` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pep8-naming`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 92
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 42
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 33
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 10
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pexpect`

### Upstream repo URL

[https://github.com/pexpect/pexpect](https://github.com/pexpect/pexpect)

### Stub distribution name

`types-pexpect`

### Version

The latest version of `types-pexpect` aims to provide accurate annotations for `pexpect==4.9.*`.

### Number of lines

670 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `pexpect` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `pexpect`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 226
    - Unannotated parameters: 128
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 181
    - Unannotated returns: 33
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 160
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 24
- Class definitions:
    - Total class definitions: 22
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pika`

### Extra description

The `types-pika` package contains alternate, more complete type stubs, that are maintained outside of typeshed.

### Upstream repo URL

[https://github.com/pika/pika](https://github.com/pika/pika)

### Stub distribution name

`types-pika-ts`

### Version

The latest version of `types-pika-ts` aims to provide accurate annotations for `pika==1.3.*`.

### Number of lines

2,225 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 3 unique allowlist entries for `pika` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `pika`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 632
    - Unannotated parameters: 373
    - Explicit `Any` parameters: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 34
- Returns:
    - Annotated returns: 623
    - Unannotated returns: 142
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 24
- Variables:
    - Annotated variables: 468
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 148
- Class definitions:
    - Total class definitions: 224
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `polib`

### Upstream repo URL

[https://github.com/izimobil/polib](https://github.com/izimobil/polib)

### Stub distribution name

`types-polib`

### Version

The latest version of `types-polib` aims to provide accurate annotations for `polib==1.2.*`.

### Number of lines

158 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `polib` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `polib`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 61
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 18
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 75
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 45
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 8
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pony`

### Upstream repo URL

[https://github.com/ponyorm/pony](https://github.com/ponyorm/pony)

### Stub distribution name

`types-pony`

### Version

The latest version of `types-pony` aims to provide accurate annotations for `pony==0.7.*`.

### Number of lines

3,596 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 9 unique allowlist entries for `pony` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `pony`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 505
    - Unannotated parameters: 1,671
    - Explicit `Any` parameters: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 2
- Returns:
    - Annotated returns: 675
    - Unannotated returns: 868
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 9
- Variables:
    - Annotated variables: 994
    - Explicit `Any` variables: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 494
- Class definitions:
    - Total class definitions: 394
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 4

---

## Info on typeshed's stubs for `portpicker`

### Upstream repo URL

[https://github.com/google/python_portpicker](https://github.com/google/python_portpicker)

### Stub distribution name

`types-portpicker`

### Version

The latest version of `types-portpicker` aims to provide accurate annotations for `portpicker==1.6.*`.

### Number of lines

16 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `portpicker` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `portpicker`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 10
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 6
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `protobuf`

### Extra description

Partially generated using [mypy-protobuf==3.6.0](https://github.com/nipunn1313/mypy-protobuf/tree/v3.6.0) and libprotoc 31.1 on [protobuf v32.1](https://github.com/protocolbuffers/protobuf/releases/tag/v32.1) (python `protobuf==6.32.1`).

### Upstream repo URL

[https://github.com/protocolbuffers/protobuf](https://github.com/protocolbuffers/protobuf)

### Stub distribution name

`types-protobuf`

### Version

The latest version of `types-protobuf` aims to provide accurate annotations for `protobuf~=6.32.1`.

### Number of lines

6,167 (excluding blank lines)

### Package status: *out of date*

These stubs may be out of date. In typeshed's CI, [stubtest][] tests these stubs against an older version of the runtime package than the latest that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 11 unique allowlist entries for `protobuf` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `protobuf`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 802
    - Unannotated parameters: 376
    - Explicit `Any` parameters: 17
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 582
    - Unannotated returns: 155
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1,107
    - Explicit `Any` variables: 122
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 88
- Class definitions:
    - Total class definitions: 214
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `psutil`

### Upstream repo URL

[https://github.com/giampaolo/psutil](https://github.com/giampaolo/psutil)

### Stub distribution name

`types-psutil`

### Version

The latest version of `types-psutil` aims to provide accurate annotations for `psutil==7.2.1`.

### Number of lines

2,259 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `darwin`, `linux` and `win32`.

Typeshed currently has 16 unique allowlist entries for `psutil` when running stubtest in CI.

### Pyright settings in CI: *strict on some files*

Some files in this stubs package are tested with the stricter pyright settings in typeshed's CI; some are excluded from the stricter settings.

### Statistics on the annotations in typeshed's stubs for `psutil`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 508
    - Unannotated parameters: 2
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 1
- Returns:
    - Annotated returns: 688
    - Unannotated returns: 1
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 3
- Variables:
    - Annotated variables: 675
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 89
- Class definitions:
    - Total class definitions: 100
    - Class definitions with `Any`: 3
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `psycopg2`

### Upstream repo URL

[https://github.com/psycopg/psycopg2](https://github.com/psycopg/psycopg2)

### Stub distribution name

`types-psycopg2`

### Version

The latest version of `types-psycopg2` aims to provide accurate annotations for `psycopg2==2.9.11`.

### Number of lines

1,759 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 unique allowlist entries for `psycopg2` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `psycopg2`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 311
    - Unannotated parameters: 176
    - Explicit `Any` parameters: 14
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 1
- Returns:
    - Annotated returns: 316
    - Unannotated returns: 73
    - Explicit `Any` returns: 21
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 6
- Variables:
    - Annotated variables: 521
    - Explicit `Any` variables: 60
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 3
- Class definitions:
    - Total class definitions: 332
    - Class definitions with `Any`: 2
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `punq`

### Upstream repo URL

[https://github.com/bobthemighty/punq](https://github.com/bobthemighty/punq)

### Stub distribution name

`types-punq`

### Version

The latest version of `types-punq` aims to provide accurate annotations for `punq==0.7.*`.

### Number of lines

82 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `punq` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `punq`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 44
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 9
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 23
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 13
    - Explicit `Any` variables: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 12
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pyRFC3339`

### Upstream repo URL

[https://github.com/kurtraschke/pyRFC3339](https://github.com/kurtraschke/pyRFC3339)

### Stub distribution name

`types-pyRFC3339`

### Version

The latest version of `types-pyRFC3339` aims to provide accurate annotations for `pyRFC3339~=2.0.1`.

### Number of lines

8 (excluding blank lines)

### Package status: *obsolete*

The runtime package has added inline type hints; these typeshed stubs are now obsolete.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `pyRFC3339` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pyRFC3339`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 8
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 3
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pyasn1`

### Upstream repo URL

[https://github.com/pyasn1/pyasn1](https://github.com/pyasn1/pyasn1)

### Stub distribution name

`types-pyasn1`

### Version

The latest version of `types-pyasn1` aims to provide accurate annotations for `pyasn1==0.6.*`.

### Number of lines

1,484 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `pyasn1` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `pyasn1`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 197
    - Unannotated parameters: 535
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 33
- Returns:
    - Annotated returns: 112
    - Unannotated returns: 422
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 9
- Variables:
    - Annotated variables: 248
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1
- Class definitions:
    - Total class definitions: 178
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pyaudio`

### Stub distribution name

`types-pyaudio`

### Version

The latest version of `types-pyaudio` aims to provide accurate annotations for `pyaudio==0.2.*`.

### Number of lines

165 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `darwin` and `linux`.

Typeshed currently has 0 allowlist entries for `pyaudio` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pyaudio`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 51
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 37
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 72
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 3
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pycocotools`

### Upstream repo URL

[https://github.com/ppwwyyxx/cocoapi](https://github.com/ppwwyyxx/cocoapi)

### Stub distribution name

`types-pycocotools`

### Version

The latest version of `types-pycocotools` aims to provide accurate annotations for `pycocotools==2.0.*`.

### Number of lines

171 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `pycocotools` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pycocotools`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 51
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 35
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 70
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 12
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pycurl`

### Upstream repo URL

[https://github.com/pycurl/pycurl](https://github.com/pycurl/pycurl)

### Stub distribution name

`types-pycurl`

### Version

The latest version of `types-pycurl` aims to provide accurate annotations for `pycurl==7.45.7`.

### Number of lines

731 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `darwin`, `linux` and `win32`.

Typeshed currently has 0 allowlist entries for `pycurl` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `pycurl`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 17
    - Unannotated parameters: 5
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 28
    - Unannotated returns: 4
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 4
- Variables:
    - Annotated variables: 683
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 4
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pyfarmhash`

### Upstream repo URL

[https://github.com/veelion/python-farmhash](https://github.com/veelion/python-farmhash)

### Stub distribution name

`types-pyfarmhash`

### Version

The latest version of `types-pyfarmhash` aims to provide accurate annotations for `pyfarmhash==0.4.*`.

### Number of lines

9 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `pyfarmhash` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pyfarmhash`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 13
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 9
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pyflakes`

### Upstream repo URL

[https://github.com/PyCQA/pyflakes](https://github.com/PyCQA/pyflakes)

### Stub distribution name

`types-pyflakes`

### Version

The latest version of `types-pyflakes` aims to provide accurate annotations for `pyflakes==3.4.*`.

### Number of lines

472 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 27 unique allowlist entries for `pyflakes` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pyflakes`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 344
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 216
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 77
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 77
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pyinstaller`

### Upstream repo URL

[https://github.com/pyinstaller/pyinstaller](https://github.com/pyinstaller/pyinstaller)

### Stub distribution name

`types-pyinstaller`

### Version

The latest version of `types-pyinstaller` aims to provide accurate annotations for `pyinstaller==6.18.*`.

### Number of lines

770 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 49 unique allowlist entries for `pyinstaller` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pyinstaller`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 305
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 167
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 224
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 31
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pyjks`

### Upstream repo URL

[https://github.com/kurtbrose/pyjks](https://github.com/kurtbrose/pyjks)

### Stub distribution name

`types-pyjks`

### Version

The latest version of `types-pyjks` aims to provide accurate annotations for `pyjks==20.0.*`.

### Number of lines

377 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 38 unique allowlist entries for `pyjks` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pyjks`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 132
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 59
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 73
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 31
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pyluach`

### Upstream repo URL

[https://github.com/simlist/pyluach](https://github.com/simlist/pyluach)

### Stub distribution name

`types-pyluach`

### Version

The latest version of `types-pyluach` aims to provide accurate annotations for `pyluach==2.3.*`.

### Number of lines

271 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `pyluach` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pyluach`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 163
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 127
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 35
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 17
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pynput`

### Upstream repo URL

[https://github.com/moses-palmer/pynput](https://github.com/moses-palmer/pynput)

### Stub distribution name

`types-pynput`

### Version

The latest version of `types-pynput` aims to provide accurate annotations for `pynput~=1.8.1`.

### Number of lines

333 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `darwin`, `linux` and `win32`.

Typeshed currently has 12 unique allowlist entries for `pynput` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pynput`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 87
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 11
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 71
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 63
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 24
    - Class definitions with `Any`: 2
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pyperclip`

### Upstream repo URL

[https://github.com/asweigart/pyperclip](https://github.com/asweigart/pyperclip)

### Stub distribution name

`types-pyperclip`

### Version

The latest version of `types-pyperclip` aims to provide accurate annotations for `pyperclip==1.9.*`.

### Number of lines

18 (excluding blank lines)

### Package status: *out of date*

These stubs may be out of date. In typeshed's CI, [stubtest][] tests these stubs against an older version of the runtime package than the latest that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `darwin`, `linux` and `win32`.

Typeshed currently has 1 unique allowlist entry for `pyperclip` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pyperclip`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 3
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 6
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 3
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pyserial`

### Upstream repo URL

[https://github.com/pyserial/pyserial](https://github.com/pyserial/pyserial)

### Stub distribution name

`types-pyserial`

### Version

The latest version of `types-pyserial` aims to provide accurate annotations for `pyserial==3.5.*`.

### Number of lines

1,173 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `darwin`, `linux` and `win32`.

Typeshed currently has 65 unique allowlist entries for `pyserial` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pyserial`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 224
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 271
    - Unannotated returns: 0
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 466
    - Explicit `Any` variables: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 65
- Class definitions:
    - Total class definitions: 68
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pysftp`

### Upstream repo URL

[https://bitbucket.org/dundeemt/pysftp](https://bitbucket.org/dundeemt/pysftp)

### Stub distribution name

`types-pysftp`

### Version

The latest version of `types-pysftp` aims to provide accurate annotations for `pysftp==0.2.*`.

### Number of lines

166 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `pysftp` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pysftp`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 109
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 70
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 6
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 6
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pytest-lazy-fixture`

### Upstream repo URL

[https://github.com/tvorog/pytest-lazy-fixture](https://github.com/tvorog/pytest-lazy-fixture)

### Stub distribution name

`types-pytest-lazy-fixture`

### Version

The latest version of `types-pytest-lazy-fixture` aims to provide accurate annotations for `pytest-lazy-fixture==0.6.*`.

### Number of lines

12 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 8 unique allowlist entries for `pytest-lazy-fixture` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pytest-lazy-fixture`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 5
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 5
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `python-crontab`

### Upstream repo URL

[https://gitlab.com/doctormo/python-crontab](https://gitlab.com/doctormo/python-crontab)

### Stub distribution name

`types-python-crontab`

### Version

The latest version of `types-python-crontab` aims to provide accurate annotations for `python-crontab==3.3.*`.

### Number of lines

355 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 3 unique allowlist entries for `python-crontab` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `python-crontab`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 183
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 13
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 153
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 80
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 19
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `python-dateutil`

### Upstream repo URL

[https://github.com/dateutil/dateutil](https://github.com/dateutil/dateutil)

### Stub distribution name

`types-python-dateutil`

### Version

The latest version of `types-python-dateutil` aims to provide accurate annotations for `python-dateutil==2.9.*`.

### Number of lines

742 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 11 unique allowlist entries for `python-dateutil` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `python-dateutil`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 306
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 186
    - Unannotated returns: 5
    - Explicit `Any` returns: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 151
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 40
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `python-http-client`

### Upstream repo URL

[https://github.com/sendgrid/python-http-client](https://github.com/sendgrid/python-http-client)

### Stub distribution name

`types-python-http-client`

### Version

The latest version of `types-python-http-client` aims to provide accurate annotations for `python-http-client==3.3.7`.

### Number of lines

76 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `python-http-client` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `python-http-client`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 15
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 13
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 12
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 14
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `python-jenkins`

### Upstream repo URL

[https://opendev.org/jjb/python-jenkins](https://opendev.org/jjb/python-jenkins)

### Stub distribution name

`types-python-jenkins`

### Version

The latest version of `types-python-jenkins` aims to provide accurate annotations for `python-jenkins~=1.8.3`.

### Number of lines

259 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `python-jenkins` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `python-jenkins`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 198
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 7
- Returns:
    - Annotated returns: 102
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 80
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 2
- Class definitions:
    - Total class definitions: 10
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `python-jose`

### Upstream repo URL

[https://github.com/mpdavis/python-jose](https://github.com/mpdavis/python-jose)

### Stub distribution name

`types-python-jose`

### Version

The latest version of `types-python-jose` aims to provide accurate annotations for `python-jose==3.5.*`.

### Number of lines

359 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 6 unique allowlist entries for `python-jose` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `python-jose`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 83
    - Unannotated parameters: 43
    - Explicit `Any` parameters: 14
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 65
    - Unannotated returns: 26
    - Explicit `Any` returns: 12
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 119
    - Explicit `Any` variables: 30
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 26
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `python-nmap`

### Upstream repo URL

[https://bitbucket.org/xael/python-nmap](https://bitbucket.org/xael/python-nmap)

### Stub distribution name

`types-python-nmap`

### Version

The latest version of `types-python-nmap` aims to provide accurate annotations for `python-nmap==0.7.*`.

### Number of lines

127 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `python-nmap` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `python-nmap`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 44
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 44
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 31
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 14
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `python-xlib`

### Upstream repo URL

[https://github.com/python-xlib/python-xlib](https://github.com/python-xlib/python-xlib)

### Stub distribution name

`types-python-xlib`

### Version

The latest version of `types-python-xlib` aims to provide accurate annotations for `python-xlib==0.33.*`.

### Number of lines

5,423 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 11 unique allowlist entries for `python-xlib` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `python-xlib`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1,334
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 15
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 583
    - Unannotated returns: 0
    - Explicit `Any` returns: 8
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 3,519
    - Explicit `Any` variables: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 425
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pytz`

### Upstream repo URL

[https://github.com/stub42/pytz](https://github.com/stub42/pytz)

### Stub distribution name

`types-pytz`

### Version

The latest version of `types-pytz` aims to provide accurate annotations for `pytz==2025.2`.

### Number of lines

151 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 4 unique allowlist entries for `pytz` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pytz`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 71
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 51
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 30
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 16
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pywin32`

### Upstream repo URL

[https://github.com/mhammond/pywin32](https://github.com/mhammond/pywin32)

### Stub distribution name

`types-pywin32`

### Version

The latest version of `types-pywin32` aims to provide accurate annotations for `pywin32==311.*`.

### Number of lines

39,362 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `win32` only.

Typeshed currently has 37 unique allowlist entries for `pywin32` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `pywin32`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 3,874
    - Unannotated parameters: 3,642
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 413
- Returns:
    - Annotated returns: 4,003
    - Unannotated returns: 1,965
    - Explicit `Any` returns: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 284
- Variables:
    - Annotated variables: 29,473
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 2,858
- Class definitions:
    - Total class definitions: 749
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pyxdg`

### Upstream repo URL

[https://github.com/takluyver/pyxdg](https://github.com/takluyver/pyxdg)

### Stub distribution name

`types-pyxdg`

### Version

The latest version of `types-pyxdg` aims to provide accurate annotations for `pyxdg==0.28.*`.

### Number of lines

858 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 unique allowlist entries for `pyxdg` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pyxdg`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 512
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 297
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 165
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 31
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `qrbill`

### Upstream repo URL

[https://github.com/claudep/swiss-qr-bill](https://github.com/claudep/swiss-qr-bill)

### Stub distribution name

`types-qrbill`

### Version

The latest version of `types-qrbill` aims to provide accurate annotations for `qrbill==1.2.*`.

### Number of lines

182 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 unique allowlist entries for `qrbill` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `qrbill`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 99
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 31
    - Unannotated returns: 0
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 40
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 4
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `qrcode`

### Upstream repo URL

[https://github.com/lincolnloop/python-qrcode](https://github.com/lincolnloop/python-qrcode)

### Stub distribution name

`types-qrcode`

### Version

The latest version of `types-qrcode` aims to provide accurate annotations for `qrcode==8.2.*`.

### Number of lines

651 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 10 unique allowlist entries for `qrcode` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `qrcode`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 282
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 21
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 152
    - Unannotated returns: 0
    - Explicit `Any` returns: 8
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 151
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 42
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `ratelimit`

### Upstream repo URL

[https://github.com/tomasbasham/ratelimit](https://github.com/tomasbasham/ratelimit)

### Stub distribution name

`types-ratelimit`

### Version

The latest version of `types-ratelimit` aims to provide accurate annotations for `ratelimit==2.2.*`.

### Number of lines

19 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `ratelimit` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `ratelimit`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 8
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 4
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 2
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `regex`

### Upstream repo URL

[https://github.com/mrabarnett/mrab-regex](https://github.com/mrabarnett/mrab-regex)

### Stub distribution name

`types-regex`

### Version

The latest version of `types-regex` aims to provide accurate annotations for `regex==2026.1.15`.

### Number of lines

910 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 12 unique allowlist entries for `regex` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `regex`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 433
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 25
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 114
    - Unannotated returns: 0
    - Explicit `Any` returns: 16
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 3
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 7
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `reportlab`

### Upstream repo URL

[https://github.com/MrBitBucket/reportlab-mirror](https://github.com/MrBitBucket/reportlab-mirror)

### Stub distribution name

`types-reportlab`

### Version

The latest version of `types-reportlab` aims to provide accurate annotations for `reportlab==4.4.9`.

### Number of lines

7,968 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 52 unique allowlist entries for `reportlab` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `reportlab`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1,797
    - Unannotated parameters: 2,567
    - Explicit `Any` parameters: 26
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 10
- Returns:
    - Annotated returns: 1,599
    - Unannotated returns: 971
    - Explicit `Any` returns: 12
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 8
- Variables:
    - Annotated variables: 2,764
    - Explicit `Any` variables: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1,172
- Class definitions:
    - Total class definitions: 583
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 3

---

## Info on typeshed's stubs for `requests`

### Extra description

Note: `types-requests` has required `urllib3>=2` since v2.31.0.7. If you need to install `types-requests` into an environment that must also have `urllib3<2` installed into it, you will have to use `types-requests<2.31.0.7`.

### Upstream repo URL

[https://github.com/psf/requests](https://github.com/psf/requests)

### Stub distribution name

`types-requests`

### Version

The latest version of `types-requests` aims to provide accurate annotations for `requests~=2.32.4`.

### Number of lines

1,044 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 4 unique allowlist entries for `requests` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `requests`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 382
    - Unannotated parameters: 132
    - Explicit `Any` parameters: 8
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 135
    - Unannotated returns: 65
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 4
- Variables:
    - Annotated variables: 126
    - Explicit `Any` variables: 15
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 20
- Class definitions:
    - Total class definitions: 53
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `requests-oauthlib`

### Upstream repo URL

[https://github.com/requests/requests-oauthlib](https://github.com/requests/requests-oauthlib)

### Stub distribution name

`types-requests-oauthlib`

### Version

The latest version of `types-requests-oauthlib` aims to provide accurate annotations for `requests-oauthlib==2.0.*`.

### Number of lines

272 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `requests-oauthlib` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `requests-oauthlib`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 68
    - Unannotated parameters: 69
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 2
- Returns:
    - Annotated returns: 45
    - Unannotated returns: 4
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 3
- Variables:
    - Annotated variables: 25
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 7
- Class definitions:
    - Total class definitions: 13
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `retry`

### Upstream repo URL

[https://github.com/invl/retry](https://github.com/invl/retry)

### Stub distribution name

`types-retry`

### Version

The latest version of `types-retry` aims to provide accurate annotations for `retry==0.9.*`.

### Number of lines

29 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 3 unique allowlist entries for `retry` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `retry`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 17
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `rfc3339-validator`

### Upstream repo URL

[https://github.com/naimetti/rfc3339-validator](https://github.com/naimetti/rfc3339-validator)

### Stub distribution name

`types-rfc3339-validator`

### Version

The latest version of `types-rfc3339-validator` aims to provide accurate annotations for `rfc3339-validator==0.1.*`.

### Number of lines

8 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `rfc3339-validator` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `rfc3339-validator`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 1
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 5
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `s2clientprotocol`

### Extra description

Partially generated using [mypy-protobuf==3.6.0](https://github.com/nipunn1313/mypy-protobuf/tree/v3.6.0) and libprotoc 27.2 on [s2client-proto 5.0.12.91115.0](https://github.com/Blizzard/s2client-proto/tree/c04df4adbe274858a4eb8417175ee32ad02fd609).

### Upstream repo URL

[https://github.com/Blizzard/s2client-proto](https://github.com/Blizzard/s2client-proto)

### Stub distribution name

`types-s2clientprotocol`

### Version

The latest version of `types-s2clientprotocol` aims to provide accurate annotations for `s2clientprotocol==5.*`.

### Number of lines

6,947 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `s2clientprotocol` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `s2clientprotocol`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 856
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 676
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1,864
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 239
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `seaborn`

### Upstream repo URL

[https://github.com/mwaskom/seaborn](https://github.com/mwaskom/seaborn)

### Stub distribution name

`types-seaborn`

### Version

The latest version of `types-seaborn` aims to provide accurate annotations for `seaborn==0.13.2`.

### Number of lines

2,608 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 4 unique allowlist entries for `seaborn` when running stubtest in CI.

### Pyright settings in CI: *entirely excluded*

All files in this stubs package are excluded from the pyright check in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `seaborn`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1,455
    - Unannotated parameters: 25
    - Explicit `Any` parameters: 156
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 18
- Returns:
    - Annotated returns: 358
    - Unannotated returns: 2
    - Explicit `Any` returns: 18
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 5
- Variables:
    - Annotated variables: 288
    - Explicit `Any` variables: 13
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 14
- Class definitions:
    - Total class definitions: 101
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `setuptools`

### Extra description

Given that `pkg_resources` is typed since `setuptools >= 71.1`, it is no longer included with `types-setuptools`.

### Upstream repo URL

[https://github.com/pypa/setuptools](https://github.com/pypa/setuptools)

### Stub distribution name

`types-setuptools`

### Version

The latest version of `types-setuptools` aims to provide accurate annotations for `setuptools==80.10.*`.

### Number of lines

2,814 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` and `win32`.

Typeshed currently has 76 unique allowlist entries for `setuptools` when running stubtest in CI.

### Pyright settings in CI: *strict on some files*

Some files in this stubs package are tested with the stricter pyright settings in typeshed's CI; some are excluded from the stricter settings.

### Statistics on the annotations in typeshed's stubs for `setuptools`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 916
    - Unannotated parameters: 239
    - Explicit `Any` parameters: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 14
- Returns:
    - Annotated returns: 729
    - Unannotated returns: 109
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 11
- Variables:
    - Annotated variables: 581
    - Explicit `Any` variables: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 198
- Class definitions:
    - Total class definitions: 123
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `shapely`

### Upstream repo URL

[https://github.com/shapely/shapely](https://github.com/shapely/shapely)

### Stub distribution name

`types-shapely`

### Version

The latest version of `types-shapely` aims to provide accurate annotations for `shapely==2.1.*`.

### Number of lines

2,862 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 3 unique allowlist entries for `shapely` when running stubtest in CI.

### Pyright settings in CI: *entirely excluded*

All files in this stubs package are excluded from the pyright check in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `shapely`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1,534
    - Unannotated parameters: 427
    - Explicit `Any` parameters: 14
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 741
    - Unannotated returns: 0
    - Explicit `Any` returns: 15
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 167
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1
- Class definitions:
    - Total class definitions: 42
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `simple-websocket`

### Upstream repo URL

[https://github.com/miguelgrinberg/simple-websocket](https://github.com/miguelgrinberg/simple-websocket)

### Stub distribution name

`types-simple-websocket`

### Version

The latest version of `types-simple-websocket` aims to provide accurate annotations for `simple-websocket==1.1.*`.

### Number of lines

304 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `simple-websocket` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `simple-websocket`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 108
    - Unannotated parameters: 1
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 44
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 77
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1
- Class definitions:
    - Total class definitions: 18
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `simplejson`

### Upstream repo URL

[https://github.com/simplejson/simplejson](https://github.com/simplejson/simplejson)

### Stub distribution name

`types-simplejson`

### Version

The latest version of `types-simplejson` aims to provide accurate annotations for `simplejson==3.20.*`.

### Number of lines

292 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 10 unique allowlist entries for `simplejson` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `simplejson`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 179
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 46
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 24
    - Unannotated returns: 0
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 49
    - Explicit `Any` variables: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 6
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `singledispatch`

### Upstream repo URL

[https://github.com/jaraco/singledispatch](https://github.com/jaraco/singledispatch)

### Stub distribution name

`types-singledispatch`

### Version

The latest version of `types-singledispatch` aims to provide accurate annotations for `singledispatch==4.1.*`.

### Number of lines

29 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `singledispatch` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `singledispatch`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 16
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 12
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 3
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 2
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `six`

### Upstream repo URL

[https://github.com/benjaminp/six](https://github.com/benjaminp/six)

### Stub distribution name

`types-six`

### Version

The latest version of `types-six` aims to provide accurate annotations for `six==1.17.*`.

### Number of lines

331 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 22 unique allowlist entries for `six` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `six`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 69
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 8
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 38
    - Unannotated returns: 0
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 13
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 3
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `slumber`

### Upstream repo URL

[https://github.com/samgiles/slumber](https://github.com/samgiles/slumber)

### Stub distribution name

`types-slumber`

### Version

The latest version of `types-slumber` aims to provide accurate annotations for `slumber==0.7.*`.

### Number of lines

72 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `slumber` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `slumber`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 42
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 24
    - Unannotated returns: 0
    - Explicit `Any` returns: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 9
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 15
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for the stdlib

### Upstream repo URL

[https://github.com/python/cpython](https://github.com/python/cpython)

### Number of lines

69,637 (excluding blank lines)

### Package status: *stdlib*

These are typeshed's stubs for the standard library. Typeshed's stdlib stubs are generally fairly up to date, and are tested against all currently supported Python versions in typeshed's CI.

### Upload status: *not currently uploaded*

These stubs are not currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `darwin`, `linux` and `win32`.

Typeshed currently has 845 unique allowlist entries for the stdlib when running stubtest in CI.

### Pyright settings in CI: *strict on some files*

Some files in this stubs package are tested with the stricter pyright settings in typeshed's CI; some are excluded from the stricter settings.

### Statistics on the annotations in typeshed's stubs for the stdlib

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 30,424
    - Unannotated parameters: 546
    - Explicit `Any` parameters: 2,088
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 11
- Returns:
    - Annotated returns: 16,818
    - Unannotated returns: 204
    - Explicit `Any` returns: 851
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 22
- Variables:
    - Annotated variables: 9,535
    - Explicit `Any` variables: 309
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 221
- Class definitions:
    - Total class definitions: 3,212
    - Class definitions with `Any`: 30
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `str2bool`

### Upstream repo URL

[https://github.com/symonsoft/str2bool](https://github.com/symonsoft/str2bool)

### Stub distribution name

`types-str2bool`

### Version

The latest version of `types-str2bool` aims to provide accurate annotations for `str2bool==1.1`.

### Number of lines

6 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `str2bool` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `str2bool`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 5
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 3
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `tabulate`

### Upstream repo URL

[https://github.com/astanin/python-tabulate](https://github.com/astanin/python-tabulate)

### Stub distribution name

`types-tabulate`

### Version

The latest version of `types-tabulate` aims to provide accurate annotations for `tabulate==0.9.*`.

### Number of lines

61 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `tabulate` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `tabulate`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 15
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 3
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 26
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 4
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `tensorflow`

### Extra description

Partially generated using [mypy-protobuf==3.6.0](https://github.com/nipunn1313/mypy-protobuf/tree/v3.6.0) and libprotoc 27.2 on `tensorflow==2.18.0`.

### Upstream repo URL

[https://github.com/tensorflow/tensorflow](https://github.com/tensorflow/tensorflow)

### Stub distribution name

`types-tensorflow`

### Version

The latest version of `types-tensorflow` aims to provide accurate annotations for `tensorflow~=2.18.0`.

### Number of lines

30,277 (excluding blank lines)

### Package status: *out of date*

These stubs may be out of date. In typeshed's CI, [stubtest][] tests these stubs against an older version of the runtime package than the latest that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *skipped*

Stubtest is skipped in typeshed's CI for this package.

Typeshed currently has 51 unique allowlist entries for `tensorflow` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `tensorflow`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 5,391
    - Unannotated parameters: 38
    - Explicit `Any` parameters: 60
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 12
- Returns:
    - Annotated returns: 2,939
    - Unannotated returns: 40
    - Explicit `Any` returns: 34
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 23
- Variables:
    - Annotated variables: 5,434
    - Explicit `Any` variables: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 11
- Class definitions:
    - Total class definitions: 927
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `toml`

### Upstream repo URL

[https://github.com/uiri/toml](https://github.com/uiri/toml)

### Stub distribution name

`types-toml`

### Version

The latest version of `types-toml` aims to provide accurate annotations for `toml==0.10.*`.

### Number of lines

136 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 4 unique allowlist entries for `toml` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `toml`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 71
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 21
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 41
    - Unannotated returns: 0
    - Explicit `Any` returns: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 14
    - Explicit `Any` variables: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 14
    - Class definitions with `Any`: 2
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `toposort`

### Upstream repo URL

[https://gitlab.com/ericvsmith/toposort](https://gitlab.com/ericvsmith/toposort)

### Stub distribution name

`types-toposort`

### Version

The latest version of `types-toposort` aims to provide accurate annotations for `toposort==1.10`.

### Number of lines

15 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `toposort` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `toposort`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 4
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 4
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 2
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `tqdm`

### Upstream repo URL

[https://github.com/tqdm/tqdm](https://github.com/tqdm/tqdm)

### Stub distribution name

`types-tqdm`

### Version

The latest version of `types-tqdm` aims to provide accurate annotations for `tqdm==4.67.*`.

### Number of lines

1,375 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 unique allowlist entries for `tqdm` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `tqdm`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 809
    - Unannotated parameters: 153
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 31
- Returns:
    - Annotated returns: 167
    - Unannotated returns: 27
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 7
- Variables:
    - Annotated variables: 105
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 76
- Class definitions:
    - Total class definitions: 36
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `translationstring`

### Upstream repo URL

[https://github.com/Pylons/translationstring](https://github.com/Pylons/translationstring)

### Stub distribution name

`types-translationstring`

### Version

The latest version of `types-translationstring` aims to provide accurate annotations for `translationstring==1.4.*`.

### Number of lines

80 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 4 unique allowlist entries for `translationstring` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `translationstring`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 62
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 18
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 4
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 7
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `ttkthemes`

### Upstream repo URL

[https://github.com/RedFantom/ttkthemes](https://github.com/RedFantom/ttkthemes)

### Stub distribution name

`types-ttkthemes`

### Version

The latest version of `types-ttkthemes` aims to provide accurate annotations for `ttkthemes==3.3.*`.

### Number of lines

126 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 4 unique allowlist entries for `ttkthemes` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `ttkthemes`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 79
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 23
    - Unannotated returns: 0
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 5
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 3
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `tzdata`

### Upstream repo URL

[https://github.com/python/tzdata](https://github.com/python/tzdata)

### Stub distribution name

`types-tzdata`

### Version

The latest version of `types-tzdata` aims to provide accurate annotations for `tzdata==2025.*`.

### Number of lines

3 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `tzdata` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `tzdata`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 0
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 0
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 2
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `uWSGI`

### Extra description

Type hints for uWSGI's [Python API](https://uwsgi-docs.readthedocs.io/en/latest/PythonModule.html). Note that this API is available only when running Python code inside a uWSGI process and some parts of the API are only present when corresponding configuration options have been enabled.

### Upstream repo URL

[https://github.com/unbit/uwsgi](https://github.com/unbit/uwsgi)

### Stub distribution name

`types-uWSGI`

### Version

The latest version of `types-uWSGI` aims to provide accurate annotations for `uWSGI==2.0.*`.

### Number of lines

382 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `darwin` and `linux`.

Typeshed currently has 9 unique allowlist entries for `uWSGI` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `uWSGI`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 338
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 15
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 216
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 61
    - Explicit `Any` variables: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 26
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `ujson`

### Upstream repo URL

[https://github.com/ultrajson/ultrajson](https://github.com/ultrajson/ultrajson)

### Stub distribution name

`types-ujson`

### Version

The latest version of `types-ujson` aims to provide accurate annotations for `ujson==5.10.*`.

### Number of lines

49 (excluding blank lines)

### Package status: *obsolete*

The runtime package has added inline type hints; these typeshed stubs are now obsolete.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `ujson` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `ujson`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 40
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 6
    - Unannotated returns: 0
    - Explicit `Any` returns: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `unidiff`

### Upstream repo URL

[https://github.com/matiasb/python-unidiff](https://github.com/matiasb/python-unidiff)

### Stub distribution name

`types-unidiff`

### Version

The latest version of `types-unidiff` aims to provide accurate annotations for `unidiff==0.7.*`.

### Number of lines

144 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 6 unique allowlist entries for `unidiff` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `unidiff`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 34
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 32
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 38
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 6
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `untangle`

### Upstream repo URL

[https://github.com/stchris/untangle](https://github.com/stchris/untangle)

### Stub distribution name

`types-untangle`

### Version

The latest version of `types-untangle` aims to provide accurate annotations for `untangle==1.2.*`.

### Number of lines

33 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `untangle` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `untangle`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 19
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 21
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 5
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 2
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `usersettings`

### Upstream repo URL

[https://github.com/glvnst/usersettings](https://github.com/glvnst/usersettings)

### Stub distribution name

`types-usersettings`

### Version

The latest version of `types-usersettings` aims to provide accurate annotations for `usersettings==1.1.*`.

### Number of lines

12 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 3 unique allowlist entries for `usersettings` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `usersettings`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 7
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 6
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 3
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `vobject`

### Upstream repo URL

[https://github.com/py-vobject/vobject](https://github.com/py-vobject/vobject)

### Stub distribution name

`types-vobject`

### Version

The latest version of `types-vobject` aims to provide accurate annotations for `vobject~=0.9.9`.

### Number of lines

557 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 7 unique allowlist entries for `vobject` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `vobject`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 172
    - Unannotated parameters: 122
    - Explicit `Any` parameters: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 1
- Returns:
    - Annotated returns: 131
    - Unannotated returns: 50
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 4
- Variables:
    - Annotated variables: 174
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 37
- Class definitions:
    - Total class definitions: 51
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `waitress`

### Upstream repo URL

[https://github.com/Pylons/waitress](https://github.com/Pylons/waitress)

### Stub distribution name

`types-waitress`

### Version

The latest version of `types-waitress` aims to provide accurate annotations for `waitress~=3.0.1`.

### Number of lines

639 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` and `win32`.

Typeshed currently has 2 unique allowlist entries for `waitress` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `waitress`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 196
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 198
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 244
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 38
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `watchpoints`

### Upstream repo URL

[https://github.com/gaogaotiantian/watchpoints](https://github.com/gaogaotiantian/watchpoints)

### Stub distribution name

`types-watchpoints`

### Version

The latest version of `types-watchpoints` aims to provide accurate annotations for `watchpoints==0.2.5`.

### Number of lines

147 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `watchpoints` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `watchpoints`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 54
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 26
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 32
    - Explicit `Any` variables: 9
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 4
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `webencodings`

### Upstream repo URL

[https://github.com/gsnedders/python-webencodings](https://github.com/gsnedders/python-webencodings)

### Stub distribution name

`types-webencodings`

### Version

The latest version of `types-webencodings` aims to provide accurate annotations for `webencodings==0.5.*`.

### Number of lines

48 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `webencodings` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `webencodings`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 32
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 16
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 12
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 8
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `whatthepatch`

### Upstream repo URL

[https://github.com/cscorley/whatthepatch](https://github.com/cscorley/whatthepatch)

### Stub distribution name

`types-whatthepatch`

### Version

The latest version of `types-whatthepatch` aims to provide accurate annotations for `whatthepatch==1.0.*`.

### Number of lines

102 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `whatthepatch` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `whatthepatch`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 32
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 25
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 54
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 9
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `workalendar`

### Upstream repo URL

[https://github.com/workalendar/workalendar](https://github.com/workalendar/workalendar)

### Stub distribution name

`types-workalendar`

### Version

The latest version of `types-workalendar` aims to provide accurate annotations for `workalendar==17.0.*`.

### Number of lines

1,861 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 5 unique allowlist entries for `workalendar` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `workalendar`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 271
    - Unannotated parameters: 23
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 235
    - Unannotated returns: 3
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 199
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 2
- Class definitions:
    - Total class definitions: 374
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `wurlitzer`

### Upstream repo URL

[https://github.com/minrk/wurlitzer](https://github.com/minrk/wurlitzer)

### Stub distribution name

`types-wurlitzer`

### Version

The latest version of `types-wurlitzer` aims to provide accurate annotations for `wurlitzer==3.1.*`.

### Number of lines

140 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `wurlitzer` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `wurlitzer`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 95
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 33
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 9
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 3
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `www-authenticate`

### Upstream repo URL

[https://github.com/alexsdutton/www-authenticate](https://github.com/alexsdutton/www-authenticate)

### Stub distribution name

`types-www-authenticate`

### Version

The latest version of `types-www-authenticate` aims to provide accurate annotations for `www-authenticate==0.9.*`.

### Number of lines

29 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `www-authenticate` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `www-authenticate`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 17
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 12
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 3
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `xdgenvpy`

### Upstream repo URL

[https://gitlab.com/deliberist-group/xdgenvpy](https://gitlab.com/deliberist-group/xdgenvpy)

### Stub distribution name

`types-xdgenvpy`

### Version

The latest version of `types-xdgenvpy` aims to provide accurate annotations for `xdgenvpy==3.0.*`.

### Number of lines

40 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `xdgenvpy` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `xdgenvpy`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 23
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 3
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `xlrd`

### Upstream repo URL

[https://github.com/python-excel/xlrd](https://github.com/python-excel/xlrd)

### Stub distribution name

`types-xlrd`

### Version

The latest version of `types-xlrd` aims to provide accurate annotations for `xlrd==2.0.*`.

### Number of lines

778 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `xlrd` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `xlrd`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 298
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 142
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 426
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 33
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `xmldiff`

### Upstream repo URL

[https://github.com/Shoobx/xmldiff](https://github.com/Shoobx/xmldiff)

### Stub distribution name

`types-xmldiff`

### Version

The latest version of `types-xmldiff` aims to provide accurate annotations for `xmldiff==2.7.*`.

### Number of lines

297 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `xmldiff` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `xmldiff`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 36
    - Unannotated parameters: 167
    - Explicit `Any` parameters: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 51
    - Unannotated returns: 57
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 10
- Variables:
    - Annotated variables: 90
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 43
- Class definitions:
    - Total class definitions: 24
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `xmltodict`

### Upstream repo URL

[https://github.com/martinblech/xmltodict](https://github.com/martinblech/xmltodict)

### Stub distribution name

`types-xmltodict`

### Version

The latest version of `types-xmltodict` aims to provide accurate annotations for `xmltodict~=1.0.1`.

### Number of lines

118 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `xmltodict` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `xmltodict`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 76
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 10
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 19
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 2
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `yt-dlp`

### Upstream repo URL

[https://github.com/yt-dlp/yt-dlp](https://github.com/yt-dlp/yt-dlp)

### Stub distribution name

`types-yt-dlp`

### Version

The latest version of `types-yt-dlp` aims to provide accurate annotations for `yt-dlp==2025.12.08`.

### Number of lines

3,501 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 19 unique allowlist entries for `yt-dlp` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `yt-dlp`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 2,029
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 280
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 922
    - Unannotated returns: 0
    - Explicit `Any` returns: 131
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 499
    - Explicit `Any` variables: 29
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 190
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `zstd`

### Upstream repo URL

[https://github.com/sergey-dryabzhinsky/python-zstd](https://github.com/sergey-dryabzhinsky/python-zstd)

### Stub distribution name

`types-zstd`

### Version

The latest version of `types-zstd` aims to provide accurate annotations for `zstd~=1.5.7.3`.

### Number of lines

37 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `zstd` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `zstd`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 6
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 23
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `zxcvbn`

### Upstream repo URL

[https://github.com/dwolfhub/zxcvbn-python](https://github.com/dwolfhub/zxcvbn-python)

### Stub distribution name

`types-zxcvbn`

### Version

The latest version of `types-zxcvbn` aims to provide accurate annotations for `zxcvbn==4.5.*`.

### Number of lines

173 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 unique allowlist entry for `zxcvbn` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `zxcvbn`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 64
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 39
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 76
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 9
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

[stubtest]: https://mypy.readthedocs.io/en/stable/stubtest.html "A tool shipped with the mypy type checker for automatically verifying that stubs are consistent with the runtime package"
